function [decomp_bands,band_powers,band_ratios] = Band_Decomposition(...
    input_signal)
% BAND_DECOMPOSITION spectrally decomposes a signal into various defined
% frequency bands.
% 
% decomp_bands = Band_Decomposition(input_signal) computes the spectrally
% decomposed bands of 'input_signal' using frequency limits defined by the
% global variable 'bands', and the iterative loop of the function
% 'Isolate_Band' for the total number of bands (denoted by the global
% variable 'num_bands'). The data is saved as matrix whose first row 
% contains 'input_signal', and the last row contains the signal for any 
% remaining power not included within these specific freqency bands.
% 
% [decomp_bands,band_powers,band_ratios] = Band_Decomposition(input_signal)
% returns the decomposed bands, as well as the power contained within each
% band and their ratio to the original power obtained from 'input_signal'.
% 
% See also ISOLATE_BAND, SEQUENCE_POWER_DISTRIBUTION, 
% BAND_DECOMPOSITION_PLOT.
%
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global num_bands bands

% Creating a matrix to save signal for each band
decomp_bands = zeros(num_bands+2,length(input_signal));

% First row is original input_signal 
decomp_bands(1,:) = input_signal;

% Creating a matrix to save power of each band
band_powers = zeros(num_bands+1,1);

% Seperate the signal into its separate bands
for k = 1:num_bands
    
    % Defining the limits of the band
    lower_limit = bands(k,1);
    upper_limit = bands(k,2);
    
    % Isolate band from signal
    [decomp_signal,band_power,original_power] = Isolate_Band(...
        input_signal,lower_limit,upper_limit);
    
    % Saving the band signal and band power to the matricies
    decomp_bands(k+1,:) = decomp_signal;
    band_powers(k,:) = band_power;
           
end

% Working out the remaining signal and power due to frequencies outside of
% the defined frequency band ranges
decomp_bands(num_bands+2,:) = 2.*input_signal-sum(decomp_bands)';
band_powers(num_bands+1,:) = original_power-sum(band_powers);

% Calculate the power ratios for each band to the original signal
band_ratios = band_powers./original_power;