function [corr_time,corrs,max_corrs,max_times] = CrossCorrelation(...
    comp_channels,comp_segments)
% CROSSCORRELATION computes the cross-correlation values between a
% reference segment and user-selected comparison segments
% 
% [corr_time,corrs,max_corrs,max_times] = CrossCorrelation(comp_channels,
% comp_segments) calculates the cross-correlation values between a
% reference segment (located in the first layer of 'comp_segments') and
% user-selected comparison segments (labelled according to 'comp_channels',
% with data situated in all remaining layers of 'comp_segments') using the
% 'xcorr' function. These correlation values are then saved in a matrix and
% returned to the parent function, alongside a matrix containing the times
% at which these values occur as 'corrs' and 'corr_time' respectively. 
% In addition, the maximum correlation value and time at which this occurs 
% is also returned as 'max_corrs' and 'max_times' respectively.
% 
% See also XCORR.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.47pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global num_bands segment_length

% Determines the number of comparison channels
num_comps = length(comp_channels);

% Initialising saving matrices
corrs = zeros(num_bands+2,2*segment_length-1,num_comps);
max_corrs = zeros(num_bands,num_comps);
max_times = zeros(num_bands,num_comps);

% Determining the cross-correlation for all comparison channels and bands
for jj = 1:num_comps    
    for ii = 1:num_bands+2
        
        % Calculate cross-correlation and the times at which this occurs
        [corrs(ii,:,jj),corr_time] = xcorr(comp_segments(ii,:,1),...
            comp_segments(ii,:,jj+1),'coeff');
        
        % Calculating the maximum cross-correlation values and the indices
        % at which they occur
        [max_corrs(ii,jj),max_corr_index] = max(corrs(ii,:,jj));
        
        % Determining the time at which the maximum cross-correlation
        % values occur
        max_times(ii,jj) = corr_time(max_corr_index);
    
    end    
end
