function varargout = GUI_CustomBands(varargin)
% GUI_CUSTOMBANDS is the programmed GUI for customising neural frequency 
% bands that appears in the program 'LFP Analysis Software 2009'.
% 
% varargout = GUI_CustomBands(varargin) accepts the position of the parent
% callback window as the first input variable, and customises the band
% names and their corresponding limits according to user-inputted strings.
%
% See also NOTCHFILTERHIDDEN.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading required global variables
global bands band_names num_bands default_band_settings

% Setting the default band names
DefaultStr = default_band_settings{1};
CBandNameStr = cell(1,2*(length(DefaultStr)));

% Extracting the default band names
for jj = 1:length(DefaultStr)
    
    % Setting the cells to contain a separate band name
    CBandNameStr{(jj*2)-1} = DefaultStr{jj};
    
    % Inserting a semicolon between each band name
    CBandNameStr{jj*2} = '; ';
end

% Converting the cell array to a string array
CBandNameStr = cell2mat(CBandNameStr);

% Setting the default band frequency limits
CBandNumStr = mat2str(default_band_settings{2});
CBandNumStr(1) = []; CBandNumStr(end) = [];

% Extracting the parent callback function position from the input variable
inputPos = varargin{1};

% Initialising a matrix for the position data of the Custom Bands figure
% window
CBandPos = zeros(size(inputPos));

% Setting the width and height of the figure window
CBandPos(3) = 75; CBandPos(4) = 15;

% Calculating the position of the figure window so that it is centred on
% the parent window
CBandPos(1) = ((inputPos(3)-CBandPos(3))/2)+inputPos(1);
CBandPos(2) = ((inputPos(4)-CBandPos(4))/2)+inputPos(2);

% Initialising a matrix to extract the current set band names
StartStr = cell(1,2*(length(band_names)-1));

% Extracting the current band names except for 'Other Frequencies'
for jj = 1:length(band_names)-1
    
    % Setting the cells to contain a separate band name
    StartStr{(jj*2)-1} = band_names{jj};
    
    % Inserting a semicolon between each band name
    StartStr{jj*2} = '; ';
end

% Removing the final semicolon
StartStr(end) = [];

% Converting the cell array to a string array
StartStr = cell2mat(StartStr);

% Converting the current band limits to a string
StartBands = mat2str(bands);

% Removing the brackets enclosing the matrix at either end of the string
StartBands(1) = []; StartBands(end) = [];

% Setting saving variables
orig_str = []; orig_val = []; input_str = []; input_val = []; 
return_str = []; return_val = [];

% Generating the custom bands figure window
CBandFigure = figure('Units','characters','MenuBar','none','Name',...
    'Custom Neural Bands','NumberTitle','off','Position',CBandPos,...
    'ReSize','off','Visible','off');

% Adding copyright text to the bottom right-hand corner of the window
CBandCopyText = uicontrol('Parent',CBandFigure,'Units','characters',...
    'BackgroundColor',get(CBandFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 CBandPos(3) 1],'String',['Copyright 2009: ',...
    'Eric Young & Andy Kingston '],'Style','text','FontSize',7);

% Creating the required panels for name and limit text fields
CBandNamePanel = uipanel('Parent',CBandFigure,'Units','characters',...
    'Position',[2 9.5 71 5]);
CBandNumPanel = uipanel('Parent',CBandFigure,'Units','characters',...
    'Position',[2 4 71 5]);

% Defining the label for the custom names text field
CBandNameTitle = uicontrol('Parent',CBandNamePanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.9 0.2],'String',['Enter the Names for these Custom ',...
    'Bands'],'Style','text');

% Creating a text field for the custom names
CBandNameTextField = uicontrol('Parent',CBandNamePanel,'Units',...
    'normalized','BackgroundColor','w','Callback',@CBandNameCallback,...
    'Enable','on','Position',[0.05 0.35 0.9 0.3],'String',StartStr,...
    'Style','edit','TooltipString',['For Greek symbols, use ''\'' ',...
    'before the symbol name, e.g. \alpha & \Alpha for Alpha symbol in ',...
    'lower- and upper-case respectively']);

% Adding a tip on how to enter the band names to the bottom right of the
% panel
CBandNameHint = uicontrol('Parent',CBandNamePanel,'Units','normalized',...
    'HorizontalAlignment','right','Position',[0.05 0.15 0.9 0.2],...
    'String','Please insert a semicolon after each name','Style','text');

% Labelling the custom limits text field
CBandNumTitle = uicontrol('Parent',CBandNumPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.9 0.2],'String',['Enter the Values of these Custom ',...
    'Bands'],'Style','text');

% Creating a text field for the custom limits
CBandNumTextField = uicontrol('Parent',CBandNumPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',@CBandNumCallback,...
    'Enable','off','Position',[0.05 0.35 0.9 0.3],'String',...
    StartBands,'Style','edit','TooltipString',...
    ['Please enter numerical values for a lower- and upper-limit for ',...
    'each band']);

% Adding a tip on how to enter the band limits to the bottom right of the
% panel
CBandNameHint = uicontrol('Parent',CBandNumPanel,'Units','normalized',...
    'HorizontalAlignment','right','Position',[0.05 0.15 0.9 0.2],...
    'String',['Leave a space between limits, & a semicolon after',...
    ' each band'],'Style','text');

% Creating a 'Restore Default Settings?' check box 
CBandDefault = uicontrol('Parent',CBandFigure,'Units','characters',...
    'BackgroundColor',get(CBandFigure,'Color'),'Callback',...
    @CBandDefaultCallback,'HorizontalAlignment','left','Position',...
    [2 2 30 1],'String','Restore Default Settings?','Style','checkbox');

% Creating a 'Set Custom Neural Bands' button
CBandButton = uicontrol('Parent',CBandFigure,'Units','characters',...
    'Callback',@CBandButtonCallback,'Enable','off','Position',...
    [32 1.5 41 2],'String','Set Custom Neural Bands');

% Making the figure window visible once initialisation is complete
set(CBandFigure,'Visible','on')

% Making the program wait until this function has been completed
uiwait(gcf)

    function CBandNameCallback(hObject,eventdata,handles)
        
        % Obtaining the custom names string
        input_str = get(hObject,'String');
        
        % Locating where separate names by finding the semicolon
        scolon = strfind(input_str,';');
        
        % Checking if more than one name has been entered
        if isempty(scolon)          
            
            % Setting the band name to the inputted string if there is only
            % one name
            orig_str = {input_str};
            
        else
            
            % Determining the number of band names if there are multiple
            % names
            cell_length = length(scolon);
            
            % Checking to see if there is another band name at the end of
            % the string without a semicolon proceeding it
            if scolon(end)<length(input_str)
                
                % Increasing the length of the saving cell to accomodate
                % the final entry
                cell_length = cell_length+1;
                
            end
            
            % Creating a saving cell for the band names according to the
            % number of names in existence
            orig_str = cell(cell_length,1);
            
            % Setting the first custom name to the first cell
            orig_str{1,1} = input_str(1:scolon(1)-1);
            
            % Running through all available band names
            for jj = 2:length(scolon)
                
                % Assigning all other custom names to the cell array
                % accordingly
                orig_str{jj,1} = input_str(scolon(jj-1)+1:scolon(jj)-1);
                
            end
            
            % Checking to see if there is one more name at the end of the
            % string array that is not enclosed by a semicolon
            if isempty(orig_str{end,1})
                
                % Inputting the final name into the cell array
                orig_str{end,1} = input_str(scolon(end)+1:length(...
                    input_str));
            end           
        end
        
        % Trimming the cells to remove blank spaces before or after the
        % names
        orig_str = strtrim(orig_str);
        
        % Enabling the limit number text field
        set(CBandNumTextField,'Enable','on')
        
        % Checking to see if both text fields contain valid strings
        if ~isempty(orig_str)&&~isempty(orig_val)
            
            % Enabling the 'Set Custom Neural Bands' button
            set(CBandButton,'Enable','on')
            
        else
            
            % Disabling the 'Set Custom Neural Bands' button
            set(CBandButton,'Enable','off')
            
        end
    end

    function CBandNumCallback(hObject,eventdata,handles)
        
        % Extracting the string within the limit text field
        input_val = get(hObject,'String');
        
        % Converting the string to a numerical matrix
        orig_val = str2num(input_val);
        
        % Determining the size of the numerical matrix
        orig_val_size = size(orig_val);
        
        % Checking that the inputted values are valid
        if isempty(orig_val)
            
            % String that is displayed if the text field contains
            % non-numerical values
            set(hObject,'String','NaN');
            
            % Stops the program
            return
            
        elseif size(orig_val,2)~=2
            
            % String displayed if more or less than two values are entered
            % per band name
            set(hObject,'String',['Only Two Numerical Values per Band ',...
                'Allowed']);
            
            % Stops the program
            return
            
        elseif isempty(orig_str)
            
            % String displayed if no band names are displayed (shouldn't
            % really ever be displayed)
            set(hObject,'String','Please Insert Band Names First');
            
            % Stops the program
            return
            
        elseif orig_val_size(1)~=size(orig_str,1)
            
            % Checks that there are two values per band
            set(hObject,'String','Must be Two Limits per Band');
            
            % Stops the program
            return
            
        end
        
        % Checks that there are valid strings entered into both text fields
        if ~isempty(orig_str)&&~isempty(orig_val)
            
            % Enables the 'Set Custom Neural Bands' button
            set(CBandButton,'Enable','on')
            
        else
            
            % Disables the 'Set Custom Neural Bands' button
            set(CBandButton,'Enable','off')
            
        end
    end

    function CBandDefaultCallback(hObject,eventdata,handles)
        
        % Checks if the default settings check box has been ticked
        if get(CBandDefault,'Value')==1
            
            % Applies the default name string to the name text field
            set(CBandNameTextField,'String',CBandNameStr)
            
            % Applies the default limit string to the limit text field
            set(CBandNumTextField,'String',CBandNumStr)
            
            % Enables the 'Set Custom Neural Bands' button
            set(CBandButton,'Enable','on')
            
            % Disables the name text field to prevent editing
            set(CBandNumTextField,'Enable','off')
            
            % Disables the limit text field to prevent editing
            set(CBandNameTextField,'Enable','off')
            
        else
            
            % Restores the inputted string to the name text field
            set(CBandNameTextField,'Enable','on','String',input_str)
            
            % Restores the inputted string to the limit text field
            set(CBandNumTextField,'String',input_val)
            
            % Checks if the limit text field is empty
            if ~isempty(input_val)
                
                % Enables the text field if it isn't empty
                set(CBandNumTextField,'Enable','on')
                
            end
            
            % Checks if both text fields are empty
            if isempty(orig_str)&&isempty(orig_val)
                
                % Disables the 'Set Custom Neural Bands'
                set(CBandButton,'Enable','off')
                
            end
        end
    end

    function CBandButtonCallback(hObject,eventdata,handles)
        
        % Checks if the default settins check box is ticked
        if get(CBandDefault,'Value')==1
            
            % Run the callback functions now to obtain the band names and
            % limits
            CBandNameCallback(CBandNameTextField);
            CBandNumCallback(CBandNumTextField);
            
            % Creates a cell array to store the band names
            return_str = cell(length(orig_str),1);
            
        else
            
            % Creates a cell array to store the band names
            return_str = cell(length(orig_str)+1,1);
            
        end
        
        % Selects each band name
        for jj = 1:length(orig_str)
            
            % Enters each band name into a corresponding cell
            return_str{jj} = orig_str{jj};
            
        end
        
        % Sets the final cell to 'Other Frequencies'
        return_str{end} = 'Other Frequencies';
        
        % Sets the band limits
        return_val = orig_val;
        
        % Sets the global variables 'bands' and 'band_names'
        bands = return_val; band_names = return_str;
        
        % Sets the global variable 'num_bands'
        num_bands = size(bands,1);
        
        % Resumes the program, and deletes the custom bands figure window
        uiresume(gcbf); delete(gcf);
        
    end

end