function varargout = GUI_MainWindow(varargin)
% GUI_MAINWINDOW is the programmed GUI for the Main Window that appears in 
% the program 'LFP Analysis Software 2009'.
% 
% varargout = GUI_MainWindow(varargin) loads the Main Window, which allows
% the user to load a data file, select a reference channel, view its plot
% against time, modify the sample rate & voltage scale, select a segment
% (either manually or via sequential segmentation), view the segment plot
% against time, view signal information, and select other analysis
% techniques.
% 
% To modify the default neural bands, and the sample rate, edit the
% variables listed in the 'Default Settings' section of the code. Please
% refer to the documentation before editing any code.
% 
% See also GUI_SEQUENTIALSEGMENTATION, TIME_SEQUENCE, GUI_ALTERNATESEGMENT,
% GUI_SINGLECHANNELANALYSIS, PSD, SPECTROGRAM, BAND_DECOMPOSITION,
% SEGMENT_POWER_DISTRIBUTION, SEQUENCE_POWER_DISTRIBUTION,
% GUI_MULTICHANNELANALYSIS, SIGNALCOMPARISON, CROSSCORRELATION, 
% PHASECOHERENCE.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%DEFAULT SETTINGS%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%REFER TO DOCUMENATION BEFORE EDITING%%%%%%%%%%%%%%%%%%%%

% Neural band names; enter names within curly brackets with a semicolon
% after each name (except the last name), as shown here,
band_labels = {'\delta'; '\theta'; '\alpha'; '\beta'; '\gamma'};

% Neural band limits; enter two limits per band (numerical values only)
% with a space between each limit, and a semicolon between each band inside
% square brackets
band_limits = [0 3; 3 7; 7 12; 12 30; 30 100];

% Sample rate; enter a numerical value only
SampleRate = 1000;

% Default voltage setting; kV = 1, V = 2, mV = 3, microV = 4, nV = 5.
VoltageSelNum = 4;

%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT BELOW THIS POINT%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading required global variables
global reference_channel sample_rate channel_length channel_time t1 t2
global VoltageScale VoltageValue segment_length num_segment bands num_bands
global band_names sequence_counter default_band_settings

% Setting the global variables for neural bands
bands = band_limits; band_names = [band_labels; 'Other Frequencies']; 
num_bands = size(bands,1);

% Setting the default global band settings
default_band_settings = {band_labels,band_limits};

% Create a saving variable for the file location
mSignalFile = [];

% Create a logical counter to detect the use of sequential segmentation
sequence_counter = 0;

% Generating the main figure window
MainFigure = figure('Units','characters','MenuBar','none','Name',...
    'Main Window','NumberTitle','off','Position',[25 3 150 55],'ReSize',...
    'off','Visible','off');

% Adding copyright text to the bottom right-hand side of the figure window
MainCopyText = uicontrol('Parent',MainFigure,'Units','characters',...
    'BackgroundColor',get(MainFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 150 1],'String',['Copyright 2009: Eric ',...
    'Young & Andy Kingston '],'Style','text','FontSize',7);

% Generating the required panels in the figure window for object
% construction
MainPlotPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[2 25.5 146 29]);
MainLoadFilePanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[2 21 96 4],'Title','1. Load a Signal File');
MainRefSelectPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[2 1 37 19.5],'Title','2. Select a Reference Channel');
MainSigInfoPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[40 14.5 58 6],'Title','3. Enter Signal Information');
MainSegmentPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[40 1 58 13],'Title','4. Select a Segment of the Signal');
MainInfoPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'fontWeight','bold','Position',[99 14.5 49 10.5],'Title',...
    'Signal Information');
MainAnalysisPanel = uipanel('Parent',MainFigure,'Units','characters',...
    'Position',[99 1 49 13],'Title','5. Choose Analysis Techniques');

% Setting the string for the load file text field
MainLoadFileText = 'Type or Browse for the Signal File';

% Setting the information section string labels
MainInfoText = {'Signal Start Time:','Signal End Time:',...
    'Number of Points:','Minimum Voltage:','Maximum Voltage:',...
    'Segment Start Time:','Segment End Time:','Segment Duration:'};

% Setting the strings for the voltage scale drop-down list
VoltageName = {'kV','V','mV','microV','nV'};

% Displayed voltage scale strings (allows for Greek letters)
VoltageScale = {'kV','V','mV','\muV','nV'};

% String of available analysis techniques for the function list box 
FunctionName = {'Save Segments to Workspace','Single Channel Analysis',...
    '--- Power Spectral Density (PSD)','--- Spectrogram',...
    '--- Spectral Decomposition','--- Power Distribution Analysis',...
    'Multi-Channel Analysis','--- Signal Comparison',...
    '--- Cross-Correlation','--- Phase Analysis'};

% Setting the string for the warning message
WarningMsg = {['Changing the Reference Channel and/or ',...
    'the Sample Rate will reset all parameters and analyses.'],...
    'Do you wish to continue?'};

% Loading icons for the plot manipulation buttons
zoomplus = load([matlabroot,'/toolbox/matlab/icons/zoomplus.mat']);
zoomminus = load([matlabroot,'/toolbox/matlab/icons/zoomminus.mat']);
panbtn = load([matlabroot,'/toolbox/matlab/icons/pan.mat']);
undock = load('undock.mat');

% Creating plot axes for the reference channel signal
MainChannelPlotAxes = axes('Parent',MainPlotPanel,'Units','normalized',...
    'OuterPosition',[0 0.5 1 0.5]);

% Plot manipulation buttons for the reference channel plot axes
MainChannelZoomIn = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.93 0.84375 0.04 0.08],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
MainChannelZoomOut = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.93 0.76375 0.04 0.08],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
MainChannelPan = uicontrol('Parent',MainPlotPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.93 0.67375 0.04 0.08],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
MainChannelUnDock = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,MainChannelPlotAxes},'CData',...
    undock.cdata,'Position',[0.93 0.59375 0.04 0.08],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Creating plot axes for the reference segment signal
MainSegmentPlotAxes = axes('Parent',MainPlotPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 0.5]);

% Plot manipulation buttons for the reference segment plot axes
MainSegmentZoomIn = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.93 0.34375 0.04 0.08],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
MainSegmentZoomOut = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.93 0.26375 0.04 0.08],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
MainSegmentPan = uicontrol('Parent',MainPlotPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.93 0.17375 0.04 0.08],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
MainSegmentUnDock = uicontrol('Parent',MainPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,MainSegmentPlotAxes},'CData',...
    undock.cdata,'Position',[0.93 0.09375 0.04 0.08],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Locating all plot manipulation buttons
allToggleBtns = findall(gcf,'Style','togglebutton');

% Load file text field
MainLoadFileTextField = uicontrol('Parent',MainLoadFilePanel,'Units',...
    'normalized','BackgroundColor','w','ButtondownFcn',...
    @LoadFileTextButtonDown,'Callback',@MainLoadFileTextCallback,...
    'Enable','inactive','HorizontalAlignment','left','Position',...
    [0.01 0.25 0.87 0.5],'String',MainLoadFileText,'Style','edit');

% Load file button - opens file dialogue window
MainLoadFileButton = uicontrol('Parent',MainLoadFilePanel,'Units',...
    'normalized','Callback',@MainLoadFileButtonCallback,'Position',...
    [0.89 0.25 0.1 0.5],'String','...','ToolTipString',...
    'Import Signal From Matlab file');

% Reference channel selection list box
MainRefSelectListBox = uicontrol('Parent',MainRefSelectPanel,'Units',...
    'normalized','Enable','off','HorizontalAlignment','left',...
    'Position',[0.05 0.22 0.9 0.73],'String',[],'Style','listbox',...
    'TooltipString','Select the Reference Channel Variable','Value',1);

% 'Select a Reference Channel' button
MainRefSelectButton = uicontrol('Parent',MainRefSelectPanel,'Units',...
    'characters','Callback',@MainRefSelectButtonCallback,'Enable',...
    'off','Position',[1.85 0.75 33.3 2.5],'String',...
    'Select a Reference Channel');

% Sample rate title
MainSampleRateText = uicontrol('Parent',MainSigInfoPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.6 0.25 0.25],'String','Sample Rate:','Style','text');

% Sample rate units
MainHzText = uicontrol('Parent',MainSigInfoPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.85 0.61 0.1 0.25],'String','Hz','Style','text');

% Sample rate text field
MainSampleRateTextField = uicontrol('Parent',MainSigInfoPanel,'Units',...
    'normalized','Callback',@MainSampleRateTextCallback,'Enable','off',...
    'Position',[0.3 0.6 0.55 0.3],'String','1000','Style','edit');

% Voltage scale title
MainVoltageScaleText = uicontrol('Parent',MainSigInfoPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.15 0.5 0.25],'String','Select a Voltage Scale:','Style',...
    'text');

% Voltage scale drop-down list
MainVoltageScaleDrop = uicontrol('Parent',MainSigInfoPanel,'Units',...
    'normalized','Callback',@MainVoltageScaleSelect,'Enable',...
    'off','Position',[0.5 0.15 0.35 0.3],'String',VoltageName,'Style',...
    'popupmenu','Value',VoltageSelNum);

% Manual segmentation title
MainSegTitle1Text = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.75 0.9 0.2],'String',...
    'Enter a Segment Time Frame...','Style','text');

% Start time label
MainSegStartText = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.22 0.12],'String','Start Time:','Style','text');

% Start time units
MainSegStartS = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.7 0.65 0.05 0.12],'String','s','Style','text');

% Start time text field
MainSegStartTextField = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','Enable','off','Position',[0.27 0.65 0.43 0.15],...
    'String',[],'Style','edit');

% End time label
MainSegEndText = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.45 0.22 0.12],'String','End Time:','Style','text');

% End time units
MainSegEndS = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.7 0.45 0.05 0.12],'String','s','Style','text');

% End time text field
MainSegEndTextField = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','Enable','off','Position',[0.27 0.45 0.43 0.15],...
    'String',[],'Style','edit');

% Manual segmentation 'OK' button
MainSegTextButton = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','Callback',@MainSegTextButtonCallback,'Enable','off',...
    'Position',[0.8 0.55 0.15 0.15],'String','OK');

% Sequential segmentation title
MainSegTitle2Text = uicontrol('Parent',MainSegmentPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.2 0.9 0.2],'String',...
    '...or Use Sequential Segmentation','Style','text');

% Sequential segmentation button
MainSegSeqButton = uicontrol('Parent',MainSegmentPanel,'Units',...
    'characters','Callback',@MainSegSeqButtonCallback,'Enable','off',...
    'Position',[2.9 0.75 52.2 2.5],'String',...
    'Begin Sequential Segmentation');

% Setting the information section labels
MainChannelInfoTitleText = uicontrol('Parent',MainInfoPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Position',[0.05 0.04 0.45 0.92],'String',MainInfoText,'Style',...
    'text');

% Setting the information section values
MainChannelInfoVarText = uicontrol('Parent',MainInfoPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Position',[0.5 0.04 0.45 0.92],'String',{''},'Style',...
    'text');

% Analysis function list box
MainFunctionList = uicontrol('Parent',MainAnalysisPanel,'Units',...
    'normalized','Enable','off','HorizontalAlignment','left','Max',1,...
    'Min',1,'Position',[0.05 0.3 0.9 0.65],'String',[],'Style',...
    'listbox','TooltipString','Select Segment Analyses Techniques',...
    'Value',1);

% Analysis function selection button
MainFunctionApply = uicontrol('Parent',MainAnalysisPanel,'Units',...
    'characters','Callback',@MainFunctionApplyCallback,'Enable','off',...
    'Position',[2.45 0.75 44.1 2.5],'String',...
    'Begin Segment Signal Analysis');

% Revealing all figure handles
set(0,'ShowHiddenHandles','on')

% Locating all objects on the Main Window
allObjects = findall(MainFigure);

% Setting the sample rate
sample_rate = SampleRate;

% Check to see if there are currently any loaded variables in the base
% workspace
if ~isempty(evalin('base','who'))
    
    % Enable the reference selection list box and button if there are
    % available variables on the base workspace
    set(MainRefSelectListBox,'BackgroundColor','w','Enable','on')
    set(MainRefSelectButton,'Enable','on')
    
    % Run the load workspace variable function to add the variables to the
    % list box string
    loadWorkspaceVar();
    
end

% Make the Main Window visible now that initialisation has been completed
set(MainFigure,'Visible','on')

    function  ButtonDown(hObject,eventdata)
        
        % Clear the curent string in the parent text field if there is a
        % button down function
        set(hObject,'Enable','on','String',[])
        uicontrol(hObject);
        
    end

    function ZoomIn(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the butotn is toggled
        if get(hObject,'Value')==1
            
            % If the button is toggled, activate the zooming function
            zoom_handle = zoom;
            
            % Set the zooming function to zoom in, and to zoom only in the
            % horizontal direction
            set(zoom_handle,'Direction','in','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function ZoomOut(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check to see if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the zoom function if the button has been toggled on
            zoom_handle = zoom;
            
            % Set the zoom function to zoom out, and to only zoom in the
            % horizontal direction
            set(zoom_handle,'Direction','out','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function UnDock(hObject,eventdata,axes_handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Create a new figure window on which to export the parent plot
        SeparatePlot = figure('ReSize','on');
        
        % Copy all the objects from the parent plot axes to this new figure
        % window
        copyobj(axes_handles,SeparatePlot);
        
        % Resize the plot axes to fill the new figure window
        set(gca,'OuterPosition',[0 0 1 1])
        
    end

    function PanCallback(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Checking if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activating the pan function if the button has been toggled on
            pan_handles = pan;
            
            % Restricting the pan motion to the horizontal axis only
            set(pan_handles,'Enable','on','Motion','horizontal')
            
        else
            
            % Turning off the pan function if the button has been toggled
            % off
            pan off
            
        end
    end

    function LoadFileTextButtonDown(hObject,eventdata)
        
        % Clear the load file text button when it is selected but remove
        % the clearing function so that the user can edit the written path 
        set(hObject,'String','','Enable','on','ButtonDownFcn',[]);
        uicontrol(hObject);
        
    end

    function MainLoadFileTextCallback(hObject,eventdata)
        
        % Obtain the data file path location from the text field
        mSignalFile = get(MainLoadFileTextField,'String');
        
        % Check that the entered file is a Matlab .mat file by checking the
        % last four letters on the string (case-insensitive)
        matSearch = strncmpi(mSignalFile(end-3:end),'.mat',4);
        
        % Check that a string has been entered into the text field
        if strcmp(mSignalFile,MainLoadFileText)==0
            
            % If a string has been entered, check that it is a valid Matlab
            % .mat file
            if matSearch==0
                
                % Display this message if the file is not a Matlab .mat
                % file
                set(MainLoadFileTextField,'String',['Program uses ',...
                    'only Matlab ''.mat'' Files'])
                
                % Stops the program
                return
                
            end
            
            % If the file is valid, load it
            loadSigFile();
            
        end
    end

    function MainLoadFileButtonCallback(hObject,eventdata)
        
        % Set the open file dialogue window to only accept Matlab .mat 
        % files
        filespec = {'*.mat', 'MATLAB .MAT files (*.mat)'};
        
        % Load the open file dialogue window
        [filename,pathname] = uigetfile(filespec,'Pick a data file',pwd);
        
        % Check that the filename isn't empty
        if ~isequal(filename,0)
            
            % Set the file location variable
            mSignalFile = fullfile(pathname,filename);
            
            % Load the signal file
            loadSigFile();
            
        end
    end

    function loadSigFile
        
        % Check whether or not the analysis function list box has already
        % been enabled (indicates that there are on-going analysis
        % techniques
        if strcmp(get(MainFunctionList,'Enable'),'on')
            
            % Disable all objects in the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Load the warning message
            WarningValue = GUI_Warning({get(MainFigure,'Position'),...
                WarningMsg});
            
            % Enable all objects in the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Check the warning logical value
            if WarningValue==0
                
                % Obtaining the default background colour
                defaultColor = get(0,'defaultUicontrolBackgroundColor');
       
                % Resetting all panels to their default initial state
                set(MainSampleRateTextField,'BackgroundColor',...
                    defaultColor,'ButtondownFcn',@ButtonDown,'Enable',...
                    'off')
                set(MainVoltageScaleDrop,'BackgroundColor',defaultColor,...
                    'Enable','off','Value',3,'String',VoltageName)
                set(MainSegStartTextField,'BackgroundColor',...
                    defaultColor,'Enable','off','String',[])
                set(MainSegEndTextField,'BackgroundColor',defaultColor,...
                    'Enable','off','String',[])
                set(MainSegTextButton,'Enable','off')
                set(MainSegSeqButton,'Enable','off')
                set(MainChannelInfoVarText,'String',{''})
                FigPanelReset();
                
            end                 
        end
        
        %Check that a valid string has been entered into the text
        % field
        if strcmp(mSignalFile,MainLoadFileText)==0
            
            % Set the file location variable as the text field string
            set(MainLoadFileTextField,'String',mSignalFile)
            
            % Enable the reference selection list box
            set(MainRefSelectListBox,'BackgroundColor','w',...
                'Enable','on');
            set(MainRefSelectButton,'Enable','on');
            
            % Load the file
            evalin('base',['load ''',mSignalFile,'''']);
            
            % Extract the base workspace variables
            loadWorkspaceVar();
    
        end
    end

    function loadWorkspaceVar(hObject,eventdata,handles)
        
        % Obtaining the variable string from the base workspace
        variables = evalin('base','who');
        
        % Setting the reference channel selection list box to display the
        % base workspace variable strings
        set(MainRefSelectListBox,'String',variables);
        
        % Run through every variable
        for jj = 1:length(variables)
            
            % Evaluate each variable
            var = evalin('base',variables{jj});
            
            % Check that the variable is in the correct orientation
            if size(var,2)>size(var,1)
                
                % Re-assign the variable in the correct orientation if it
                % is not
                assignin('base',variables{jj},var') ;
                
            end
        end
    end

    function MainRefSelectButtonCallback(hObject,eventdata)
        
        % Enable the sample rate and voltage scale sections
        set(MainSampleRateTextField,'BackgroundColor','w',...
            'ButtondownFcn',@ButtonDown,'Enable','inactive')
        set(MainVoltageScaleDrop,'BackgroundColor','w',...
            'Enable','on','Value',VoltageSelNum,'String',VoltageName)
        
        % Load the variable strings from the base workspace
        variables = evalin('base','who');
        
        % Select the reference channel from these variable strings
        reference_channel = variables{get(MainRefSelectListBox,'Value')};
        uicontrol(hObject);
        
        % Check whether or not the analysis function list box has already
        % been enabled (indicates that there are on-going analysis
        % techniques
        if strcmp(get(MainFunctionList,'Enable'),'on')
            
            % Disable all objects in the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Load the warning message
            WarningValue = GUI_Warning({get(MainFigure,'Position'),...
                WarningMsg});
            
            % Enable all objects in the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Check the warning logical value
            if WarningValue==1
                
                % Clear the segment plot axes and update the reference 
                % channel plot
                cla(MainSegmentPlotAxes,'reset'); MainChannelPlot();
                
            else
                
                % Stops the program
                return
                
            end
        end
        
        % Clear the segment plot axes and update the reference channel plot
        cla(MainSegmentPlotAxes,'reset'); MainChannelPlot();
        
    end

    function MainSampleRateTextCallback(hObject,eventdata,handles)
        
        % Convert the sample rate string to a numerical value
        sample_rate = str2double(get(hObject,'String'));
        
        % Perform checks
        if isnan(sample_rate)
            
            % Display this message if it is not a numerical value
            set(MainSampleRateTextField,'String',['Must be a numerical',...
                ' value'])
            
            % Stops the program
            return
            
        elseif sample_rate<=0
            
            % Displays this message if the sample rate is less than 1Hz
            set(MainSampleRateTextField,'String',['Must be greater ',...
                'than 0Hz'])
            
            % Stops the program
            return
            
        end
        
        % Check whether or not the analysis function list box has already
        % been enabled (indicates that there are on-going analysis
        % techniques
        if strcmp(get(MainFunctionList,'Enable'),'on')
            
            % Disables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Displays the warning message
            WarningValue = GUI_Warning({get(MainFigure,'Position'),...
                WarningMsg});
            
            % Enables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Check the warning logical value
            if WarningValue==1
                
                % Clear the segment plot axes and update the reference 
                % channel plot
                cla(MainSegmentPlotAxes,'reset'); MainChannelPlot();
                
            else
                
                % Stops the program
                return
                
            end
        end
        
        % Clear the segment plot axes and update the reference channel plot 
        cla(MainSegmentPlotAxes,'reset'); MainChannelPlot();
        
    end

    function MainChannelPlot
        
        % Checks that a valid number has been entered for the sample rate
        if ~isnan(str2double(get(MainSampleRateTextField,'String')))
            
            % Obtains the voltage scale selection value
            VoltageValue = get(MainVoltageScaleDrop,'Value');
            
            % Determines the length of the reference channel signal
            channel_length = length(evalin('base',reference_channel))/...
                sample_rate;
            
            % Calculates the reference channel signal time scale
            channel_time = 0:1/sample_rate:channel_length-1/sample_rate;
            
            % Rests the function panel, updates the signal information
            % panel, and enables the segment panel
            FigPanelReset(); SigInfoSet(); SegPanelSet();
            
            % Plot the reference channel signal in the channel plot axes
            plot(MainChannelPlotAxes,channel_time,evalin('base',...
                reference_channel));
            grid(MainChannelPlotAxes);
            xlabel(MainChannelPlotAxes,'Time /s');
            ylabel(MainChannelPlotAxes,['Voltage /',...
                VoltageScale{VoltageValue}]);
            title(MainChannelPlotAxes,['Signal from Channel ',...
                reference_channel]);
            
        end
    end

    function SigInfoSet
        
        % Check if a segment has been selected yet
        if isempty(t1)||isempty(t2)
            
            % If not, display all channel signal information but no segment
            % signal information
            set(MainChannelInfoVarText,'String',{[num2str(channel_time(...
                1)),'s'],[num2str(channel_time(end)),'s'],num2str(...
                channel_length*sample_rate),[num2str(min(min(evalin(...
                'base',reference_channel)))),VoltageScale{...
                VoltageValue}],[num2str(max(max(evalin('base',...
                reference_channel)))),VoltageScale{VoltageValue}],'','',...
                ''});
            
        else
            
            % Otherwise display all available information
            set(MainChannelInfoVarText,'String',{[num2str(channel_time(...
                1)),'s'],[num2str(channel_time(end)),'s'],num2str(...
                channel_length*sample_rate),[num2str(min(min(evalin(...
                'base',reference_channel)))),VoltageScale{...
                VoltageValue}],[num2str(max(max(evalin('base',...
                reference_channel)))),VoltageScale{VoltageValue}],...
                [num2str(t1),'s'],[num2str(t2),'s'],[num2str(t2-t1),'s']});
            
        end
    end

    function MainVoltageScaleSelect(hObject,evendata,handles)
        
        % Check there is a valid number for the sample rate
        if ~isnan(str2double(get(MainSampleRateTextField,'String')))
            
            % Obtain the selected voltage value
            VoltageValue = get(MainVoltageScaleDrop,'Value');
            
            % Update the signal information units
            SigInfoSet();
            
            % Change the y-labels of the plot axes
            ylabel(MainChannelPlotAxes,['Voltage /',VoltageScale{...
                VoltageValue}]);
            ylabel(MainSegmentPlotAxes,['Voltage /',VoltageScale{...
                VoltageValue}]);
            
        end
    end

    function MainSegTextButtonCallback(hObject,eventdata,handles)
        
        % Check whether or not the analysis function list box has already
        % been enabled (indicates that there are on-going analysis
        % techniques
        if strcmp(get(MainFunctionList,'Enable'),'on')
            
            % Disable the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Display the warning message
            WarningValue = GUI_Warning({get(MainFigure,'Position'),...
                ['Changing the Segmentation Values will modify current',...
                ' Analyses. Do you wish to continue?']});
            
            % Enable the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Check the warning logical value
            if WarningValue==0
                
                % Stops the program
                return
                
            end
        end
        
        % Set the sequential segmentation indicator to off
        sequence_counter = 0;
        
        % Convert the start and end time text fields into numerical values
        t1 = str2double(get(MainSegStartTextField,'String'));
        t2 = str2double(get(MainSegEndTextField,'String'));
        
        % Determine if both are valid numbers
        numerical_error_check = isnan([t1 t2]);
        
        % Determine if they both fall within the reference channel time
        % scale
        time_error_check = [t1<channel_time(1),t2>(round(channel_time(...
            end)*sample_rate)/sample_rate)];
        
        % Handles corresponding to the start and end time text fields
        error_search = {'MainSegStartTextField','MainSegEndTextField'};
        
        % Perform checks
        if sum(numerical_error_check)>0
            
            % Locating which field(s) contain the a non-numerical value
            numerical_error_locater = find(numerical_error_check==1);
            
            % Run through for all fields
            for j = 1:length(numerical_error_locater)
                
                % Set the string to display this message
                set(eval(error_search{numerical_error_locater(j)}),...
                    'String','NaN')
                
            end
            
            % Stops the program
            return
            
        elseif sum(time_error_check)>0
            
            % Find where the entered time value falls outside of the
            % channel time scale
            time_error_locater = find(time_error_check==1);
            
            % Run through for all erroneous text fields
            for k = 1:length(time_error_locater)
                
                % Set the text field to display this message
                set(eval(error_search{time_error_locater(k)}),...
                    'String','Outside Range')
                
            end
            
            % Stops the program
            return
            
        elseif t1>=t2
            
            % Displayed if the end time is less than or equal to the start
            % time
            set(MainSegEndTextField,'String','Must be >Start Time')
            
            % Stops the program
            return
            
        else
            
            % Clears the number of segments (sequential segmentation
            % variable)
            num_segment = [];
            
            % Locates the indices of the segment within the channel signal
            segment_indices = [t1*sample_rate+1, t2*sample_rate+1];
            
            % Extracts the segment from the channel signal
            segment_signal = evalin('base',sprintf('%s(%d:%d)',...
                reference_channel,segment_indices(1),segment_indices(...
                2)));
            
            % Determines the length and time scale of the segment signal
            segment_length = length(segment_signal);
            segment_time = t1:1/sample_rate:t2;
            
            % Plot the segment signal in the segment plot axes
            MainSegPlot(segment_time,segment_signal);
            
            % Update the information panel, and enable the function list
            % panel
            SigInfoSet(); AnalysisPanelSet();
            
        end
    end

    function SegPanelSet
        
        %Enables all relevant objects in the segmentation panel
        set(MainSegStartTextField,'BackgroundColor','w','ButtondownFcn',...
            @ButtonDown,'Enable','inactive','String',...
            num2str(channel_time(1)))
        set(MainSegEndTextField,'BackgroundColor','w','ButtondownFcn',...
            @ButtonDown,'Enable','inactive','String',...
            num2str(channel_time(end)))
        set(MainSegTextButton,'Enable','on')
        set(MainSegSeqButton,'Enable','on')
        
    end

    function MainSegPlot(segment_time,segment_signal)
        
        % Disables the function panel
        FigPanelReset();
        
        % Obtains the selected voltage scale
        VoltageValue = get(MainVoltageScaleDrop,'Value');
        
        % Plots the segment signal to the segment plot axes
        plot(MainSegmentPlotAxes,segment_time,segment_signal);
        grid(MainSegmentPlotAxes)
        xlabel(MainSegmentPlotAxes,'Time /s')
        ylabel(MainSegmentPlotAxes,['Voltage /',...
            VoltageScale{VoltageValue}])
        title(MainSegmentPlotAxes,['Segment Between ',num2str(t1,...
            '%.0f'),'s and ',num2str(t2,'%.0f'),'s'])
        
    end

    function MainSegSeqButtonCallback(hObject,eventdata,handles)
        
        % Check whether or not the analysis function list box has already
        % been enabled (indicates that there are on-going analysis
        % techniques
        if strcmp(get(MainFunctionList,'Enable'),'on')
            
            % Disables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Displays the warning message
            WarningValue = GUI_Warning({get(MainFigure,'Position'),...
                ['Changing the Segmentation Values will modify current',...
                ' Analyses.'],'Do you wish to continue?'});
            
            % Enables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Checks the warning logical value
            if WarningValue==0
                
                % Stops the program
                return
                
            else
                
                % Rests the analysis panel
                FigPanelReset();
                
            end
        end
        
        % Disables the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Initiates sequential segmentation
        [segment_signal,segment_time] = GUI_SequentialSegmentation();
        
        % Enables the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Checks if a segment signal has been selected
        if ~isempty(segment_signal)||~isempty(segment_time)
            
            % Updates the start and end time text fields
            set(MainSegStartTextField,'String',num2str(t1))
            set(MainSegEndTextField,'String',num2str(t2))
            
            % Plots the segment signal in the segment plot axes
            MainSegPlot(segment_time,segment_signal);
            
            % Updates the signal information panel and enables the analysis
            % panel
            SigInfoSet(); AnalysisPanelSet();
            
        end
    end

    function AnalysisPanelSet
        
        % Enables the analysis function panel
        set(MainFunctionList,'BackgroundColor','w','Enable','on',...
            'String',FunctionName)
        set(MainFunctionApply,'Enable','on')
        
    end

    function MainFunctionApplyCallback(hObject,eventdata,handles)
        
        % Obtains the indices of the segment signal in the channel signal
        segment_indices = [t1*sample_rate+1, t2*sample_rate+1];
        
        % Extracts the segment signal from the channel signal
        segment_signal = evalin('base',sprintf('%s(%d:%d)',...
            reference_channel,segment_indices(1),segment_indices(...
            2)));
        
        % Sets a cell array to contain the segment signal and the selected
        % option from the list box
        AnalysisInput{1} = segment_signal;
        AnalysisInput{2} = get(MainFunctionList,'Value');
        
        % Checks which option has been selected
        if get(MainFunctionList,'Value')==1
            
            % Disables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
            
            % Loads 'GUI_AlternateSegment' if option 1 is selected
            GUI_AlternateSegment();
            
            % Enables the figure window
            set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
            
            % Refreshes the reference channel list box
            loadWorkspaceVar();
            
        else
            
            % Determine whether or not Single Channel or Multi-Channel
            % Analysis has been selected
            if get(MainFunctionList,'Value')<=6
                
                % Load Single Channel Analysis if the option is less than 7
                % but greater than 1
                GUI_SingleChannelAnalysis(AnalysisInput);            
                
            else
                
                % Otherwise, load Multi-Channel Analysis
                GUI_MultiChannelAnalysis(AnalysisInput);
                
            end
        end
    end

    function FigPanelReset
        
        % Get the default background colour 
        defaultColor = get(0,'defaultUicontrolBackgroundColor');
        
        % Disable the analysis function pane;
        set(MainFunctionList,'BackgroundColor',defaultColor,'Enable',...
            'off','String',[])
        set(MainFunctionApply,'Enable','off')
        
        % Get the handles of any currently open figure windows
        otherFig = get(0,'Children');
        
        % Select all other figure windows apart from the Main Window
        otherFig(find(otherFig==MainFigure)) = [];
        
        % Close all other figure windows
        close(otherFig)
        
    end
end