function GUI_MultiChannelAnalysis(varargin)
% GUI_MULTICHANNELANALYSIS is the programmed GUI for multi-channel 
% analysis that appears in the program 'LFP Analysis Software 2009'.
% 
% GUI_MultiChannelAnalysis(varargin) allows the user to perform Signal
% Comparison, Cross-Correlation, and Phase Coherence analysis for multiple
% signals as long as they are either the same length as the reference
% channel or segment.
% 
% See also SIGNALCOMPARISON, CROSSCORRELATION, PHASECOHERENCE,
% GUI_NOTCHFILTER, NOTCH_FILTER, NOTCHFILTERHIDDEN, GUI_CUSTOMBANDS,
% APPLYWINDOW, MAT2CLIP.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading the required global variables
global band_names disabledBtns sample_rate t1 t2 reference_channel 
global MC_applied_window filter_counter disp_band_names MatlabVersion
global MCprev_signal PA_counter

% Extracing the input variables
inputVar = varargin{1};

% Extracting the segment signal from the input variable
segment_signal = inputVar{1};

% Setting the string for the band selection list box
disp_band_names = ['Total Signal'; band_names];

% Generating a figure window
MCFigure = figure('Units','characters','MenuBar','none','Name',...
    'Multi-Channel Signal Analysis','NumberTitle',...
    'off','Position',[25 3 150 55],'ReSize','off','Visible','off');

% Adding copyright text to the bottom right-hand side of the figure window
MCCopyText = uicontrol('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 150 1],'String',['Copyright 2009: Eric ',...
    'Young & Andy Kingston '],'Style','text','FontSize',7);

% Creating the global control panels for the figure window
MCConPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'Position',[2 44.5 33 10],'Title','Control Panel');
MCCompPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'Position',[2 30 33 14],'Title','Select Comparison Channels');
MCBandPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'Position',[2 15.5 33 14],'Title','Select Specific Bands');
MCFilterPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'Position',[2 1 33 14],'Title','Apply Filters');

% Assigning the names for the window function drop-down list
Windows_Name = {'None','Modified Bartlett-Hann','Blackman',...
    'Blackman-Harris','Bohman','Chebyshev','Flat Top Weight Window',...
    'Gaussian','Hamming','Hann (Hanning)','Kaiser',...
    'Nuttall-Defined Blackman-Harris','Parzen (de la Valle-Poussin)',...
    'Rectangluar','Tukey','Triangular'};

% Assigning the window functions from the Signal Processing Toolbox
Windows = {'none','barthannwin','bartlett','blackman',...
    'blackmanharris','bohmanwin','chebwin','flattopwin','gausswin',...
    'hamming','hann','kaiser','nuttallwin','parzenwin','rectwin',...
    'tukeywin','triang'};

% Obtaining the list of variables currently on the base workspace
all_var = evalin('base','who');

% Variable counter to select only certain variables
var_counter = 1;

% Running through for all available variables on the base workspace;
% displays only variables of the same size as either the referenc channel
% signal or its selected segment
for kk = 1:length(all_var)
    
    % Determining the size of each variable and comparing it to the size of
    % the reference channel signal
    var_size = (sum(size(evalin('base',reference_channel))==evalin(...
        'base',['size(',all_var{kk},');']))==2);
    
    % Determining the size of each variable and comparing it to the size of
    % the reference segment signal
    seg_size = (sum(size(segment_signal)==evalin('base',['size(',...
        all_var{kk},');']))==2);
    
    % Checking if the dimensions agree
    if var_size==1 || seg_size==1
        
        % Creating a new string of desired variables only
        channels{var_counter} = all_var{kk};
        
        % Increasing the variable counter
        var_counter = var_counter+1;
        
    end
end

% Generating the comparison channel list box and its selection button
MCCompListBox = uicontrol('Parent',MCCompPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Max',length(evalin('base','who')),'Min',1,'Position',...
    [0.05 0.25 0.9 0.7],'String',channels,'Style',...
    'listbox','TooltipString','Select the Comparison Channels','Value',1);
MCCompSelectButton = uicontrol('Parent',MCCompPanel,'Units',...
    'normalized','Callback',@MCCompSelectCallback,'Position',...
    [0.25 0.05 0.5 0.15],'String','OK');

% Generating the band selection list box and its selection button
MCBandListBox = uicontrol('Parent',MCBandPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Max',length(band_names),'Min',1,'Position',[0.05 0.25 0.9 0.7],...
    'String',disp_band_names,'Style','listbox',...
    'TooltipString','Select the Comparison Channels','Value',1);
MCBandSelectButton = uicontrol('Parent',MCBandPanel,'Units',...
    'normalized','Callback',@MCBandSelectCallback,'Position',...
    [0.25 0.05 0.5 0.15],'String','OK');

% Generating the window function label and its drop-down list
MCFiltWindowText = uicontrol('Parent',MCFilterPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.85 0.9 0.1],'String','Apply a Window:','Style',...
    'text','TooltipString','Apply a Window to Signal');
MCFiltWindow = uicontrol('Parent',MCFilterPanel,'Units','normalized',...
    'BackgroundColor','w','Callback',@MCWindowCallback,'Enable','off',...
    'Position',[0.05 0.7 0.9 0.15],'String',Windows_Name,'Style',...
    'popupmenu','Value',1);

% Generating the custom bands and notch filter buttons
MCFiltBand = uicontrol('Parent',MCFilterPanel,'Units','normalized',...
    'Callback',@MCBandCallback,'FontWeight','bold','Position',...
    [0.05 0.4 0.9 0.25],'String','Custom Neural Bands?');
MCFiltNotch = uicontrol('Parent',MCFilterPanel,'Units','normalized',...
    'Callback',@MCNotchCallback,'FontWeight','bold','Position',...
    [0.05 0.1 0.9 0.25],'String','Apply Notch Filters?');

% Creating the global control buttons for the analysis panels
SCCon = uicontrol('Parent',MCConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.05 0.69 0.9 0.28],...
    'String','Signal Comparison','UserData',{'SCPlotPanel','[]'});
CCCon = uicontrol('Parent',MCConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.05 0.38 0.9 0.28],...
    'String','Cross-Correlation','UserData',{'CCPlotPanel','CCConPanel'});
PACon = uicontrol('Parent',MCConPanel,'Units','normalized',...
    'Callback',@ControlCallback,'Position',[0.05 0.05 0.9 0.28],...
    'String','Phase Analysis','UserData',{'PAPlotPanel','PAConPanel'});

% Determining the number of global control buttons in the menu
dispButtons = findall(MCConPanel,'Enable','on');
dispButtons = sort(dispButtons(1:3));

% Creating the required plot and control panels for object construction
SCPlotPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'Position',[36 1 111 53.5],...
    'Title','Signal Comparison','Visible','off','UserData','SCPlot();');
CCPlotPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'Position',[36 15.5 111 39],...
    'Title','Cross-Correlation','Visible','off','UserData','CCPlot();');
CCConPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'Position',[36 1 111 14],...
    'Title','Cross-Correlation: Data Panel','Visible','off');
PAPlotPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'Position',[36 15.5 111 39],...
    'Title','Phase Analysis','Visible','off','UserData','PAPlot();');
PAConPanel = uipanel('Parent',MCFigure,'Units','characters',...
    'BackgroundColor',get(MCFigure,'Color'),'Position',[36 1 111 14],...
    'Title','Phase Analysis: Data Panel','Visible','off');

% Determining all the objects in the figure window not including the figure
% window itself
dispPanels = findall(gcf,'Visible','off');
dispPanels(dispPanels==MCFigure) = [];

% Loading the icon files for the plot manipulation buttons
zoomplus = load([matlabroot,'/toolbox/matlab/icons/zoomplus.mat']);
zoomminus = load([matlabroot,'/toolbox/matlab/icons/zoomminus.mat']);
panbtn = load([matlabroot,'/toolbox/matlab/icons/pan.mat']);
undock = load('undock.mat');

% Creating a plot axes panel for signal comparison
SCPlotAxesPanel = uipanel('Parent',SCPlotPanel,'Units','normalized',...
    'Position',[0.01 0.01 0.98 0.99]);

% Creating a plot axes for signal comparison
SCPlotAxes = axes('Parent',SCPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Adding plot manipulation buttons to the signal comparison plots
SCPlotZoomIn = uicontrol('Parent',SCPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.926 0.56 0.05 0.043],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
SCPlotZoomOut = uicontrol('Parent',SCPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.926 0.51 0.05 0.043],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
SCPlotPan = uicontrol('Parent',SCPlotAxesPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.926 0.44 0.05 0.043],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
SCPlotUnDock = uicontrol('Parent',SCPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,SCPlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.926 0.39 0.05 0.043],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Adding a legend toggle button for the signal comparison plot
SCLegToggle = uicontrol('Parent',SCPlotAxesPanel,'Units',...
    'normalized','Callback',@ViewPowerLeg,'Position',...
    [0.74 0.0075 0.25 0.05],'String','Toggle Legend On/Off');

% Adding cross correlation plot axes and data panels
CCPlotAxesPanel = uipanel('Parent',CCPlotPanel,'Units','normalized',...
    'Position',[0.01 0.01 0.98 0.99]);
CCConFunPanel = uipanel('Parent',CCConPanel,'Units','normalized',...
    'Position',[0.005 0.01 0.99 0.99]);

% Creating the plot axes panel for the cross-correlation plots
CCPlotAxes = axes('Parent',CCPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Adding plot manipulation buttons for the cross-correlation plot axes
CCPlotZoomIn = uicontrol('Parent',CCPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.926 0.5625 0.05 0.0575],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
CCPlotZoomOut = uicontrol('Parent',CCPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.926 0.505 0.05 0.0575],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
CCPlotPan = uicontrol('Parent',CCPlotAxesPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.926 0.4375 0.05 0.0575],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
CCPlotUnDock = uicontrol('Parent',CCPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,CCPlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.926 0.38 0.05 0.0575],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Adding a legend toggle button to the cross-correlation plot axes
CCLegToggle = uicontrol('Parent',CCPlotAxesPanel,'Units','normalized',...
    'Callback',@ViewPowerLeg,'Position',[0.74 0.0075 0.25 0.05],...
    'String','Toggle Legend On/Off');

% Cross-correlation table title
CCInfoTitle = uicontrol('Parent',CCConFunPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.025 0.85 0.475 0.115],'String',...
    'Max Correlation Coefficients','Style','text');

% Copy to clipboard function for cross-correlation data
CCInfoCopy = uicontrol('Parent',CCConFunPanel,'Units','normalized',...
    'Callback',@CopyClip,'Position',[0.725 0.85 0.25 0.15],'String',...
    'Copy Table to Clipboard?','UserData','CCDataTable');

% Check for compatibility issues
if MatlabVersion>2007
    
    % Generate a table to store the data if using Matlab 7.6.0 (R2008a} or
    % higher
    CCInfoTable = uitable('Parent',CCConFunPanel,'Units','normalized',...
        'Position',[0.025 0.05 0.95 0.8]);
    
else
    
    % Replacement uicontrol if not the case
    CCCompIssue = uicontrol('Parent',CCConFunPanel,'Units','normalized',...
        'Enable','inactive','Position',[0.025 0.05 0.95 0.8],'String',...
        ['Unable to Display Table in Current Matlab Version. ',...
        'Please Refer to the User Guide.'],'Style','edit');
    
end

% Generating the phase and rose plots plot and data panels
PAPlotAxesPanel = uipanel('Parent',PAPlotPanel,'Units','normalized',...
    'Position',[0.01 0.01 0.98 0.99],'Visible','off');
PAConFunPanel = uipanel('Parent',PAConPanel,'Units','normalized',...
    'Position',[0.005 0.01 0.99 0.99],'Visible','off');
PARosePlotAxesPanel = uipanel('Parent',PAPlotPanel,'Units','normalized',...
    'Position',[0.01 0.01 0.98 0.99],'Visible','on');
PARoseConFunPanel = uipanel('Parent',PAConPanel,'Units','normalized',...
    'Position',[0.005 0.01 0.99 0.99],'Visible','on');

% Creating a plot axes for the phase plots
PAPlotAxes = axes('Parent',PAPlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Adding plot manipulation buttons to the phase plot axes
PAPlotZoomIn = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.926 0.5625 0.05 0.0575],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
PAPlotZoomOut = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.926 0.505 0.05 0.0575],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
PAPlotPan = uicontrol('Parent',PAPlotAxesPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.926 0.4375 0.05 0.0575],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
PAPlotUnDock = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,PAPlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.926 0.38 0.05 0.0575],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Phase locking label
PAPLockText = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Position',[0.01 0.0575 0.17 0.033],'String',...
    'Phase Lock Ratio:','Style','text');

% Phase locking text field
PAPLockTextField = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',...
    @PAPLockTextFieldCallback,'Position',[0.18 0.0575 0.07 0.04],...
    'Style','edit','TooltipString','Leave a Space between Ratio Values');

% Button to switch to displaying the rose plots
PARoseDispButton = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',@PARoseDispCallback,'Position',...
    [0.01 0.0075 0.25 0.05],'String','Display Rose Plots');

% Comparing the phase, rose and signal comparison plots
PAExportButton = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',@PAExportButtonCallback,'Position',...
    [0.74 0.0575 0.25 0.05],'String','Compare with Signal');

% Toggling the legend
PALegToggle = uicontrol('Parent',PAPlotAxesPanel,'Units',...
    'normalized','Callback',@ViewPowerLeg,'Position',...
    [0.74 0.0075 0.25 0.05],'String','Toggle Legend On/Off');

% Phase plot table title 
PAPCTitle = uicontrol('Parent',PAConFunPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.025 0.85 0.475 0.115],'String','Mean Phase Coherence',...
    'Style','text');

% Copy to clipboard function for the phase coherence data
PAPCCopy = uicontrol('Parent',PAConFunPanel,'Units','normalized',...
    'Callback',@CopyClip,'Position',[0.725 0.85 0.25 0.15],'String',...
    'Copy Table to Clipboard?','UserData','PAPCDataTable');

% Check for compatibility issues
if MatlabVersion>2007
    
    % Generate a table to store the data if using Matlab 7.6.0 (R2008a} or
    % higher
    PAPCTable = uitable('Parent',PAConFunPanel,'Units','normalized',...
        'Position',[0.025 0.05 0.95 0.8]);
    
else
    
    % Replacement uicontrol if not the case
    PACompIssue = uicontrol('Parent',PAConFunPanel,'Units','normalized',...
        'Enable','inactive','Position',[0.025 0.05 0.95 0.8],'String',...
        ['Unable to Display Table in Current Matlab Version. ',...
        'Please Refer to the User Guide.'],'Style','edit');
    
end

% Creating a rose plot axes
PARosePlotAxes = axes('Parent',PARosePlotAxesPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1]);

% Adding plot manipulation buttons to the rose plot axes
PARosePlotZoomIn = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.926 0.5625 0.05 0.0575],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
PARosePlotZoomOut = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.926 0.505 0.05 0.0575],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
PARosePlotPan = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@PanCallback,'CData',panbtn.cdata,...
    'Position',[0.926 0.4375 0.05 0.0575],'Style','togglebutton',...
    'TooltipString','Click to Pan along the Plot','Value',0);
PARosePlotUnDock = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',{@UnDockSub,PARosePlotAxesPanel},'CData',...
    undock.cdata,'Position',[0.926 0.38 0.05 0.0575],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Number of bins label
PARoseBinsText = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Position',[0.01 0.0575 0.15 0.033],'String',...
    'Number of Bins:','Style','text');

% Number of bins text field
PARoseBinsTextField = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',...
    @PABinsTextFieldCallback,'Position',[0.16 0.0575 0.1 0.04],'Style',...
    'edit');

% Display the phase plots button
PAPhaseDispButton = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@PARoseDispCallback,'Position',...
    [0.01 0.0075 0.25 0.05],'String','Display Phase Plots');

% Comparing the phase, rose and signal comparison plots
PARoseExportButton = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@PAExportButtonCallback,'Position',...
    [0.74 0.0575 0.25 0.05],'String','Compare with Signal');

% Toggling the legend
PARoseLegToggle = uicontrol('Parent',PARosePlotAxesPanel,'Units',...
    'normalized','Callback',@ViewPowerLeg,'Position',...
    [0.74 0.0075 0.25 0.05],'String','Toggle Legend On/Off');

% Rose plot table title
PABPTitle = uicontrol('Parent',PARoseConFunPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.025 0.85 0.475 0.115],'String',...
    'Percentage of Bin Population (in Degrees)','Style','text');

% Copy to clipboard function for the rose plot table
PABPCopy = uicontrol('Parent',PARoseConFunPanel,'Units','normalized',...
    'Callback',@CopyClip,'Position',[0.725 0.85 0.25 0.15],'String',...
    'Copy Table to Clipboard?','UserData','PABPDataTable');

% Check for compatibility issues
if MatlabVersion>2007
    
    % Generate a table to store the data if using Matlab 7.6.0 (R2008a} or
    % higher
    PABPTable = uitable('Parent',PARoseConFunPanel,'Units','normalized',...
        'Position',[0.025 0.05 0.95 0.8]);
else
    
    % Replacement uicontrol if not the case
    PABPCompIssue = uicontrol('Parent',PARoseConFunPanel,'Units',...
        'normalized','Enable','inactive','Position',...
        [0.025 0.05 0.95 0.8],'String',['Unable to Display Table in ',...
        'Current Matlab Version. Please Refer to the User Guide.'],...
        'Style','edit');
    
end

% Creating a legend panel to overlay on top of the filters panel
LegendPanel = uipanel('Parent',MCFigure,'Units','characters','Position',...
    [2 1 33 14],'Title','Legend','Visible','off');

% Adding a legend plot axes; legend will stretch over entire axes
LegendPlotAxes = axes('Parent',LegendPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 1],'XColor','w','XTick',[],'YColor','w',...
    'YTick',[]);

% Find all the plot manipulation buttons in the figure window
allToggleBtns = findall(MCFigure,'Style','togglebutton');

% Setting all the default values
comp_selection = 1; band_selection = 1; MC_applied_window = 'none'; 
nbins = 60;

% Finding all the objects in the figure window
allObjects = findall(gcf);

% Setting separate signal variables for the analysis and the phase analysis
% (latter can have windows applied to it)
MC_signal = segment_signal;
transformed_signal = segment_signal;
MCprev_signal = segment_signal;

% Setting saving variables
legendstr = []; comp_segments = []; colourorder = []; CCDataTable = [];
PAPCDataTable = []; PABPDataTable = [];

% Setting a filter counter
filter_counter = 0;

% Setting the window counter to zero
PA_counter = 0;

% Set a phase locking ratio
PLock1 = 1; PLock2 = 1;

% Setting the bins text field to display a string
set(PARoseBinsTextField,'String',num2str(nbins))

% Setting the phase locking ratio text field to display a string
set(PAPLockTextField,'String',[num2str(PLock1),' ',num2str(PLock2)])

% Plotting the functions
SCPlot();

% Setting the warning messages
WarningMsg1 = {'Applying a Window will Modify Phase Analysis.',...
    'Do you wish to continue?'};
WarningMsg2 = {['Customising Neural Bands will Reset all ',...
    'Current Analyses.'],'Do you wish to continue?'};
WarningMsg3 = {['Applying Notch Filters will Reset all ',...
    'Current Analyses.'],'Do you wish to continue?'};

% Extracts the selected option from the input variable
inputSelVar = inputVar{2}-6;

% Checks the value of the selected option
if inputSelVar<=2
    
    % Considers the PSD button selected for the first two options
    set(SCCon,'Enable','off')
    
    % Performs the relevant button callback function
    ControlCallback(SCCon);
    
else
    
    % Selects the button according to the selected option
    set(dispButtons(inputSelVar-1),'Enable','off')
    
    % Performs the relevant button callback function
    ControlCallback(dispButtons(inputSelVar-1))
    
end

% Sets the figure window to visible as initialisation is complete
set(MCFigure,'Visible','on')

    function ControlCallback(hObject,eventdata,handles)
        
        % Disable all panels and enable all control menu buttons
        set(dispPanels,'Visible','off'); set(dispButtons,'Enable','on');
        
        % Get the 'UserData' property from the parent button
        FunPanel = get(hObject,'UserData');
        
        % Evaluate the handle strings 
        PlotPanel = eval(FunPanel{1}); ConPanel = eval(FunPanel{2});
        
        % Enable the relevant plot and control panels and disable the
        % button
        set(PlotPanel,'Visible','on'); set(ConPanel,'Visible','on');
        set(hObject,'Enable','off');
        
        % Tag the currently selected button and reset the plot manipulation
        % functions
        disabledBtns = hObject; zoom off; datacursormode off; pan off;
        
        % Make the legend panel invisible and make the filter panel visible
        set(LegendPanel,'Visible','off')
        set(MCFilterPanel,'Visible','on')
        
        % Toggle off all the plot manipulation buttons
        for jj = 1:length(allToggleBtns)
            set(allToggleBtns(jj),'Value',0)
        end
        
        % Check if the phase analysis panel has been selected
        if hObject==PACon
            
            % Enable the window function drop-down list
            set(MCFiltWindow,'Enable','on')
            
        else
            % Disable the window function drop-down list
            set(MCFiltWindow,'Enable','off')
            
        end
    end

    function ZoomIn(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the butotn is toggled
        if get(hObject,'Value')==1
            
            % If the button is toggled, activate the zooming function
            zoom_handle = zoom;
            
            % Set the zooming function to zoom in, and to zoom only in the
            % horizontal direction
            set(zoom_handle,'Direction','in','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function ZoomOut(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check to see if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the zoom function if the button has been toggled on
            zoom_handle = zoom;
            
            % Set the zoom function to zoom out, and to only zoom in the
            % horizontal direction
            set(zoom_handle,'Direction','out','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
        end
    end

    function UnDockSub(hObject,eventdata,panel_handles)
         
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Locating the axes in the parent panel
        axes = findobj(panel_handles,'Type','axes');
        
        % Creating a new figure window
        SeparatePlot = figure('ReSize','on');
        
        % Copying the axes to the new figure window
        copyobj(axes,SeparatePlot);
        
        % Locating all the axes in the new figure window
        SeparatePlotAxes = sort(findobj(SeparatePlot,'Type','axes'));
        
        % Determining the number of axes plots in existence
        num_subplots = length(SeparatePlotAxes);
        
        % Calculating the width of each subplot
        dx = floor(sqrt(num_subplots));
        
        % Calculating the height of each subplot
        dy = ceil(num_subplots/dx);
        
        % Setting the initial position vector (top left)
        x = 0; y = 1-1/dy; 
        
        % Creating a saving position matrix for all subplots and setting 
        % the width and height
        pos = zeros(num_subplots,4); pos(:,3) = 1/dx; pos(:,4) = 1/dy;
        
        % Setting the position for all the subplots
        for ii = 1:num_subplots
            
            % Checking the y-direction
            if y>=0
                
                % Setting the horizontal and vertical positions
                pos(ii,1) = x; pos(ii,2) = y;
                
                % Decreasing the vertical position
                y = y-1/dy;
                
            else
                
                % Resetting the vertical position, and increasing the
                % horizontal position
                y = 1-1/dy; x = x+1/dx;
                
                % Setting the horizontal and vertical positions
                pos(ii,1) = x; pos(ii,2) = y;
                
                % Decreasing the vertical position
                y = y-1/dy;
                
            end
        end
        
        % Setting the position of all the subplots
        for kk = 1:num_subplots
            
            % Setting the 'OuterPosition' property of all the subplots
            set(SeparatePlotAxes(kk),'OuterPosition',squeeze(pos(kk,:)))
            
            % Check the parent callback panel
            if get(hObject,'Parent')==SCPlotAxesPanel
                
                % If it is the signal comparison panel, create as legend
                legend(SeparatePlotAxes(kk),[reference_channel;...
                    legendstr],'Location','EastOutside')             
                
            elseif get(hObject,'Parent')==PARosePlotAxesPanel
                
                % Obtain the list of comparison channels from the band 
                % selection list box if this is the rose plot panel
                comp_channels = get(MCCompListBox,'String');
                
                % Determining how many comparison channels have been 
                % selected
                num_comps = length(comp_channels(comp_selection));
                
                % Create a legend
                [LH OH PH TS] = legend(SeparatePlotAxes(kk),'show');
                
                % Set the legend for the rose plot panel
                legend(SeparatePlotAxes(kk),PH(end-num_comps+1:end),...
                    legendstr,'Location','BestOutside')
                
            else
                
                % Otherwise, create a legend
                legend(SeparatePlotAxes(kk),legendstr,'Location',...
                    'EastOutside')
                
            end
                
        end
    end

    function PanCallback(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];

        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Checking if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activating the pan function if the button has been toggled on
            pan_handles = pan;
            
            % Restricting the pan motion to the horizontal axis only
            set(pan_handles,'Enable','on','Motion','horizontal')
            
        else
            
            % Turning off the pan function if the button has been toggled
            % off
            pan off
            
        end
    end

    function MCCompSelectCallback(hObject,eventdata,handles)
        
        % Get the selected options from the comparison selection list box
        comp_selection = get(MCCompListBox,'Value');
        
        % Update all the plots; other plots are nested within the signal
        % comparison plot
        SCPlot();
        
    end

    function MCBandSelectCallback(hObject,eventdata,handles)
        
        % Get the selected options from the band selection list box
        band_selection = get(MCBandListBox,'Value');
        
        % Update all plots
        SCPlot();
        
    end

    function MCWindowCallback(hObject,eventdata,handles)
        
        % Determining the previously applied window function 
        prev_val = find(strcmp(MC_applied_window,Windows)==1);
        
        % Setting the new window function
        MC_applied_window = Windows{get(hObject,'Value')};
        
        % Applying the window function to the signal
        transformed_signal = ApplyWindow(MC_signal,MC_applied_window);
        
        % Setting a new default signal
        MCprev_signal = transformed_signal;
        
        % Disabling the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Displaying the warning message
        WarningValue = GUI_Warning({get(MCFigure,'Position'),...
            WarningMsg1});
        
        % Enabling the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disabling the current analysis' control button 
        set(disabledBtns,'Enable','off')
        
        % Checking the logical value returned from the warning message
        if WarningValue==1
            
            % Update the phase analysis plot
            PAPlot();
            
        else
            
            % Returning the window function drop-down menu to its previous
            % value
            set(hObject,'Value',prev_val)
            
            % Stop the program
            return
            
        end
    end

    function MCBandCallback(hObject,eventdata,handles)
        
        % Disable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Display the warning message
        WarningValue = GUI_Warning({get(MCFigure,'Position'),...
            WarningMsg2});
        
        % Enable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disable the current analysis' control menu button
        set(disabledBtns,'Enable','off')
        
        % Check the returned warning logical value
        if WarningValue==1
            
            % Run the customise bands GUI
            GUI_CustomBands(get(MCFigure,'Position'));
            
            % Set the band selection string and update the list box
            disp_band_names = ['Total Signal'; band_names];
            set(MCBandListBox,'Max',length(band_names),'String',...
                disp_band_names,'Value',1)
            
            % Update the plots
            SCPlot();
            
        else
            
            % Stops the program
            return
            
        end
    end

    function MCNotchCallback(hObject,eventdata,handles)
        
        % Gets the comparison channel strings
        comp_channels = get(MCCompListBox,'String');
        
        % Obtains the selected strings
        comp_channels = comp_channels(comp_selection);
        
        % Disable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','off')
        
        % Display the warning message
        WarningValue = GUI_Warning({get(MCFigure,'Position'),...
            WarningMsg3});
        
        % Enable the figure window
        set(allObjects(isprop(allObjects,'Enable')),'Enable','on')
        
        % Disable the current analysis' control menu button
        set(disabledBtns,'Enable','off')
        
        % Check the warning logical value
        if WarningValue==1
            
            % Set the filter counter to one
            filter_counter = 1;
            
            % Update the plots
            SCPlot();
            
        else
            
            % Set the filter counter to zero
            filter_counter = 0;
            
            % Stops the program
            return
            
        end
    end

    function SCPlot(hObject,eventdata,handles)
        
        % Check that a comparison channel has been selected
        if ~isempty(comp_selection)
            
            % Get the comparison channel strings
            comp_channels = get(MCCompListBox,'String');
            
            % Obtain the selected comparison channel
            comp_channels = comp_channels(comp_selection);

            % Obtain the matrix of segments
            comp_segments = SignalComparison(comp_channels,MC_signal);
            
            % Delete and clear the plot axes
            delete(SCPlotAxes)
            clear SCPlotAxes
            
            % Determine the segment time scale, number of selected
            % comparison channels, number of band selections, and set the
            % stacking value to zero
            segment_time = t1:1/sample_rate:t2;
            num_comps = length(comp_channels);
            num_sel = length(band_selection); stack = 0;
            
            % Run through for all the selected bands
            for ii= 1:num_sel
                
                % Create a subplot axes for each band
                SCPlotAxes(ii) = subplot(num_sel,1,ii,'Parent',...
                    SCPlotAxesPanel);
                
                % Hold the plot and remove the y-axis ticks
                hold all; set(gca,'YTick',[]);
                
                % Run through for the reference segment and all selected
                % comparison segments
                for jj = 1:num_comps+1
                    
                    % Obtaining the required band from the segment
                    plot_seg = comp_segments(band_selection(ii),:,jj);
                    
                    % Determining the location of the plot line
                    stack = stack - max(plot_seg);
                    
                    % Stack plotting the signals
                    plot(segment_time,plot_seg+stack);
                    
                    % Re-calculating the stacking function
                    stack = stack+min(plot_seg);
                    
                end
                
                % Labelling the plot axes accordingly
                xlabel(gca,'Segment Time /s'); ylabel(gca,'Amplitude'); 
                grid(gca);
                
                % Checking if 'Total Signal' has been selected
                if strcmp(disp_band_names{band_selection(ii)},...
                        'Total Signal')==1
                    
                    % Generating a title
                    title(SCPlotAxes(ii),['Compare Signals to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)}])
                    
                else
                    
                    % Generating a title
                    title(SCPlotAxes(ii),['Compare Signals to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)},' Band'])
                    
                end
            end
            
            % Generatng a legend string
            legendstr = comp_channels;
            
            % Making the legend panel invisible, and the filter panel
            % visible
            set(LegendPanel,'Visible','off')
            set(MCFilterPanel,'Visible','on')
            
        end
        
        % Shifting the colour order of the plot lines
        colourorder = circshift(get(SCPlotAxes(1),'colororder'), -1);
        
        % Continue updating plots
        CCPlot();
        
    end

    function ViewPowerLeg(hObject,eventdata)
        
        % Check if the legend panel is invisible
        if strcmp(get(LegendPanel,'Visible'),'off')
            
            % Making the filter panel invisible
            set(MCFilterPanel,'Visible','off')
            
            % Checking if the parent plot axes is the signal comparison
            % panel
            if get(hObject,'Parent')==SCPlotAxesPanel
                
                % Generating the legend plot
                plot(LegendPlotAxes,meshgrid(1:length(legendstr)+1),...
                    'Visible','off')
                
                % Creating the legend
                legend_handle = legend(LegendPlotAxes,...
                    [reference_channel;legendstr],'Location',get(...
                    LegendPlotAxes,'Position'));
                
            else
                
                % Shifting the colour order of the legend plot
                set(LegendPlotAxes,'nextplot','replacechildren',...
                    'colororder',colourorder)
                
                % Generating the legend plot
                plot(LegendPlotAxes,meshgrid(1:length(legendstr)),...
                    'Visible','off')
                
                % Creating the legend
                legend_handle = legend(LegendPlotAxes,legendstr,...
                    'Location',get(LegendPlotAxes,'Position'));
                
            end
            
            % Removing all ticks, setting a border, and making the legend
            % visible
            set(LegendPlotAxes,'XColor','w','XTick',[],'YColor',...
                'w','YTick',[])
            set(legend_handle,'Box','on')
            set(LegendPanel,'Visible','on')
            
        else
            
            % Otherwise, clear the legend plot axes
            cla(LegendPlotAxes,'reset')
            
            % Make the legend panel invisible, and the filter panel visible
            set(LegendPanel,'Visible','off')
            set(MCFilterPanel,'Visible','on')
            
        end
    end

    function CCPlot(hObject,eventdata,handles)
        
        % Check that a comparison signal has been selected
        if ~isempty(comp_selection)
            
            % Get the strings of comparison channels
            comp_channels = get(MCCompListBox,'String');
            
            % Obtain the selected channels and determine how many of them
            % there are
            comp_channels = comp_channels(comp_selection);
            num_comps = length(comp_channels);
            
            % Calculate the cross-correlation
            [corr_time,corrs,max_corrs,max_times] = CrossCorrelation(...
                comp_channels,comp_segments);
            
            % Delete and clear the cross-correlation plot axes
            delete(CCPlotAxes)
            clear CCPlotAxes
            
            % Determine the number of selected bands
            num_sel = length(band_selection);
            
            % Run through for all selected bands
            for ii= 1:num_sel
                
                % Generate a subplot axes for each band
                CCPlotAxes(ii) = subplot(num_sel,1,ii,'Parent',...
                    CCPlotAxesPanel);
                
                % Shift the colour order of this axis
                set(gca,'nextplot','replacechildren','colororder',...
                    colourorder)
                
                % Plot the cross-correlation for this band and label
                % accordingly
                plot(gca,corr_time/sample_rate,squeeze(corrs(...
                    band_selection(ii),:,:)));
                grid(gca)
                xlabel(gca,'Time Difference /s');
                ylabel(gca,'Correlation Coefficient');
                title(gca,sprintf('Cross-correlation with %s: %s',...
                    reference_channel,disp_band_names{...
                    band_selection(ii)}));
                
            end
            
            % Create a table array
            table = zeros(num_sel,2*num_comps);
            
            % Set all the maximum correlation values and time delays to the
            % table
            table(:,1:2:2*num_comps) = max_corrs(band_selection,:);
            table(:,2:2:2*num_comps) = max_times(band_selection,:)/...
                sample_rate;
            
            % Create a column label cell array
            column = cell(1,2*num_comps);
            
            % Define the column labels
            column(1,1:2:2*num_comps) = comp_channels;
            column(1,2:2:2*num_comps) = {'(time)'};
            
            % Check for compatibility issues
            if MatlabVersion>2007
                
                % Display the table data if no issues
                set(CCInfoTable,'Data',table,'ColumnName',column,...
                    'RowName',disp_band_names(band_selection));
                
            end
            
            % Define a new table to contain the labels as well; used for
            % 'Copy to Clipboard'
            CCDataTable = cell(size(table)+1);
            
            % Label the column and rows and assign the data values
            CCDataTable{1,1} = 'Band\';
            CCDataTable(1,2:end) = column;
            CCDataTable(2:end,1) = disp_band_names(band_selection);
            CCDataTable(2:end,2:end) = num2cell(table);
            
            % Update the phase analysis plot
            PAPlot();
            
        end
    end

    function PABinsTextFieldCallback(hObject,eventdata,handles)
        
        % Get the number of bins string
        nbins = str2double(get(hObject,'String'));
        
        % Check that this is a numerical value
        if isnan(nbins)
            
            % Display this message if it is not
            set(hObject,'String','NaN')
            
            % Stops the program
            return
            
        else
            
            % Update the phase analysis plot
            PAPlot();
            
        end
    end

    function PAPLockTextFieldCallback(hObject,eventdata,handles)
        
        % Get the phase locking ratio
        PRatio = str2num(get(hObject,'String'));
        
        % Check that this is a numerical value
        if isnan(PRatio)
            
            % Display this message if it is not
            set(hObject,'String','NaN')
            
            % Stops the program
            return
            
        elseif length(PRatio)~=2
            
            % Display this message if there are less/more than 2 values
            set(hObject,'String','NaN')
            
            % Stops the program
            return
            
        else
            
            % Modify the phase locking ratio values
            PLock1 = PRatio(1); PLock2 = PRatio(2);
            
            % Update the phase analysis plot
            PAPlot();
            
        end        
    end

    function PAPlot(hObject,eventdata,handles)
        
        % Check that a comparison channel has been selected
        if ~isempty(comp_selection)
            
            % Get the comparsion channel list string
            comp_channels = get(MCCompListBox,'String');
            
            % Get the selected comparison channels
            comp_channels = comp_channels(comp_selection);
            
            % Setting the window counter to one
            PA_counter = 1;
            
            % Determine the signal comparison segments
            PA_segments = SignalComparison(comp_channels,...
                transformed_signal);
            
            % Setting the window counter to zero
            PA_counter = 0;           
                    
            % Calculate the phase coherence
            [dphi,coherences] = PhaseCoherence(comp_channels,...
                PA_segments,PLock1,PLock2);
            
            % Delete and clear both the phase and rose plot axes
            delete(PAPlotAxes)
            clear PAPlotAxes
            delete(PARosePlotAxes)
            clear PARosePlotAxes
            
            % Calculate the segment time scale
            segment_time = t1:1/sample_rate:t2;
            
            % Determine the number of selected bands
            num_sel = length(band_selection);
            
            % Determining the array of bins
            edges = 0:(2*pi)/nbins:2*pi;
            
            % Initialise a table
            table = zeros(length(edges)-1,num_sel+2,length(comp_channels));
            
            % Run through for all bands
            for ii= 1:num_sel
                
                % Generate a subplot axes and shift its colour order
                PAPlotAxes(ii) = subplot(num_sel,1,ii,'Parent',...
                    PAPlotAxesPanel);
                set(PAPlotAxes(ii),'nextplot','replacechildren',...
                    'colororder',colourorder);
                
                % Plot the phase coherences
                plot(PAPlotAxes(ii),segment_time,squeeze(dphi(...
                    band_selection(ii),:,:)),'.');
                xlabel(PAPlotAxes(ii),'Time /s')
                ylabel(PAPlotAxes(ii),'Phase Difference /rads \pi^-^1')
                grid(PAPlotAxes(ii))
                
                % Check if there are less than four plots
                if num_sel<=3
                    
                    % Shift the position so it does not interfere with the
                    % plot manipulation buttons
                    set(PAPlotAxes(ii),'OuterPosition',...
                        [0 (0.1+0.8*(num_sel-ii)/num_sel) 1 0.8/num_sel]);
                    
                end
                
                % Generate a subplot axes and shift its colour order
                PARosePlotAxes(ii) = subplot(num_sel,1,ii,'Parent',...
                    PARosePlotAxesPanel);
                set(PARosePlotAxes(ii),'nextplot','replacechildren',...
                    'colororder',colourorder);
                
                % Set a grid around the axis
                grid(PARosePlotAxes(ii))
                
                % Run through for all selected comparison channels
                for jj = 1:length(comp_channels)
                    
                    % Determine the rose histogram
                    [tout,rout] = rose(squeeze(dphi(band_selection(...
                        ii),:,jj)),nbins);
                    
                    % Plot the rose histogram and hold all
                    PARosePlot = polar(PARosePlotAxes(ii),tout,rout/...
                        ((t2-t1)*sample_rate+1));
                    hold all
                    
                    % Set the lines to be thicker
                    set(PARosePlot,'LineWidth',2);
                    
                    % Count the histogram
                    hcount = histc(dphi(band_selection(ii),:,jj),...
                        edges)';
                    hcount(end-1) = hcount(end-1)+hcount(end);
                    
                    % Save the bin intervals
                    table(:,1,jj) = edges(1:length(edges)-1);
                    table(:,2,jj) = edges(2:length(edges));
                    
                    % Save the histogram count as a percentage
                    table(:,ii+2,jj) = hcount(1:end-1)/(((t2-t1)*...
                        sample_rate)+1)*100;
                    
                end
                
                % Check if 'Total Signal' has been selected
                if strcmp(disp_band_names{band_selection(ii)},...
                        'Total Signal')==1
                    
                    % Add the correct title
                    title(PAPlotAxes(ii),['Phase Difference to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)}])
                    title(PARosePlotAxes(ii),['Phase Difference to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)}])
                    
                else
                    
                    % Add the correct title
                    title(PAPlotAxes(ii),['Phase Difference to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)},' Band'])
                    title(PARosePlotAxes(ii),['Phase Difference to ',...
                        reference_channel,' in ',disp_band_names{...
                        band_selection(ii)},' Band'])
                    
                end
            end
            
            % Check for compatibility issues
            if MatlabVersion>2007
                
                % Generate a table of data if no issues found
                set(PAPCTable,'Data',coherences(band_selection,:),...
                    'ColumnName',comp_channels,'RowName',...
                    disp_band_names(band_selection)); 
                
            end
            
            % Create a cell array to save the data for the 'Copy to
            % Clipboard' function
            PAPCDataTable = cell(size(coherences(band_selection,:))+1);
            
            % Set the column and row names, and the data
            PAPCDataTable{1,1} = 'Band\Channel Name';
            PAPCDataTable(1,2:end) = comp_channels;
            PAPCDataTable(2:end,1) = disp_band_names(band_selection);
            PAPCDataTable(2:end,2:end) = num2cell(coherences(...
                band_selection,:));
            
            % Initialise a cell array for the row labels
            BPRowName = cell(size(table,1),1);
            
            % Run through for all rows
            for jj = 1:size(table,1)
                
                % Set the bin interval row label
                BPRowName{jj,1} = [num2str(180*table(jj,1,1)/pi,...
                    '%0.2f'),' - ',num2str(180*table(jj,2,1)/pi,'%0.2f')];
                
            end
            
            % Set column and data counters
            colcount = 1; datacount = 1;
            
            % Initialise arrays for the column name and data values
            BPColName = cell(size(table,2)*size(table,3),1);
            BPData = zeros(size(table,1),size(table,2)-2);
            
            % Run through for all columns
            for jj = 1:size(table,3)
                
                % Run through for all selected bands
                for kk = 1:length(band_selection)
                    
                    % Assign the column name
                    BPColName{colcount,:} = [comp_channels{jj},...
                        ' ',disp_band_names{band_selection(kk)}];
                    
                    % Increase the column counter
                    colcount = colcount+1;
                    
                end
                
                % Run through for all data columns
                for mm = 3:size(table,2)
                    
                    % Assign the data values
                    BPData(:,datacount) = table(:,mm,jj);
                    
                    % Increase the data counter
                    datacount = datacount+1;
                    
                end
            end
            
            % Check for compatibility issues
            if MatlabVersion>2007
                
                % Create a table if no issues found
                set(PABPTable,'Data',BPData,'ColumnName',BPColName,...
                    'RowName',BPRowName)
                
            end
            
            % Create a cell array for the rose plot data table for 'Copy to
            % Clipboard' function
            PABPDataTable = cell(size(BPData)+1);
            
            % Label the rows and columns, and assign data
            PABPDataTable{1,1} = 'Bins in Degrees\Channel & Band Names';
            PABPDataTable(1,2:end) = BPColName(size(BPData,2));
            PABPDataTable(2:end,1) = BPRowName;
            PABPDataTable(2:end,2:end) = num2cell(BPData);
            
        end
    end

    function PAExportButtonCallback(hObject,eventdata,handles)
        
        % Get the comparison channel strings
        comp_channels = get(MCCompListBox,'String');
        
        % Get the selected comparison channels
        comp_channels = comp_channels(comp_selection);
        
        % Get the band name strings
        band_list_names = get(MCBandListBox,'String');
        
        % Get the selected band name
        band_list_names = band_list_names(get(MCBandListBox,'Value'));
        
        % Determine the signal comparison segments
        PA_segments = SignalComparison(comp_channels,...
            transformed_signal);
        
        % Calculate a time scale for the segment
        segment_time = t1:1/sample_rate:t2;
        
        % Locate all the phase and rose plot axes
        subplot_axes = findobj(PAPlotAxesPanel,'Type','axes');
        rose_subplot_axes = findobj(PARosePlotAxesPanel,'Type','axes');
        
        % Run through for all axes
        for ii = 1:length(subplot_axes)
            
            % Create a new figure window
            SeparatePlot = figure('Name',['Phase Analysis of ',...
                band_list_names{ii}],'NumberTitle','off','ReSize','on',...
                'Visible','off');
            
            % Check if 'Total Signal' is selected
            if strcmp(band_list_names{ii},'Total Signal')==0
                
                % If not, label the figure correctly
                set(SeparatePlot,'Name',['Phase Analysis of ',...
                    band_list_names{ii},' Band'])
                
            end
            
            % Copy the phase and rose plots
            SeparatePlotAxes = copyobj(subplot_axes(ii),SeparatePlot);
            SeparateRosePlotAxes = copyobj(rose_subplot_axes(ii),...
                SeparatePlot);
            
            % Generate a legend for the phase plot
            legend(SeparatePlotAxes,comp_channels,'Location',...
                'EastOutside')
            
            % Set the position of the axes
            set(SeparatePlotAxes,'Units','normalized','OuterPosition',...
                [0 0 0.75 0.5])
            set(SeparateRosePlotAxes,'Units','normalized',...
                'Position',[0.725 0 0.25 1])
            
            % Create an original signal comparison plot
            OriginalPlotAxes = axes('Parent',gcf,'Units','normalized',...
                'OuterPosition',[0 0.5 0.75 0.5]);
            
            % Set a stacking function
            plot_stack = 0;
            
            % Run through for all selected comparison and the reference
            % channel
            for kk = 1:length(comp_channels)+1
                
                % Extract the signal comparison segment
                plot_seg = PA_segments(band_selection(ii),:,kk);
                
                % Create a stack
                plot_stack = plot_stack - max(plot_seg);
                
                % Stack plot the segment
                plot(segment_time,plot_seg+plot_stack);
                
                % Modify the stack and hold all
                plot_stack = plot_stack+min(plot_seg);
                hold all
                
            end
            
            % Label the original signal comparison plot accordingly
            xlabel(OriginalPlotAxes,'Segment Time /s')
            ylabel(OriginalPlotAxes,'Amplitude');
            grid(OriginalPlotAxes);
            
            % Check if 'Total Signal' has been selected
            if strcmp(disp_band_names{band_selection(ii)},...
                    'Total Signal')==1
                
                % Add a title accordingly
                title(OriginalPlotAxes,['Comparison to ',...
                    reference_channel,' in ',disp_band_names{...
                    band_selection(ii)}])
                
            else
                
                % Add a title accordingly
                title(OriginalPlotAxes,['Comparison to ',...
                    reference_channel,' in ',disp_band_names{...
                    band_selection(ii)},' Band'])
            end
            
            % Remove the y-axis ticks
            set(OriginalPlotAxes,'YTick',[]);
            
            % Create a legend
            legend(OriginalPlotAxes,[reference_channel;comp_channels],...
                'Location','EastOutside')
            
            % Check if 'Total Signal' has been selected
            if strcmp(band_list_names{ii},'Total Signal')==0
                
                % Re-position the axes
                set(SeparatePlotAxes,'Units','normalized',...
                    'OuterPosition',[0 1/3 0.75 1/3])
                set(OriginalPlotAxes,'Units','normalized',...
                    'OuterPosition',[0 2/3 0.75 1/3])
                
                % Add a 'Total Signal' plot axes
                TotalPlotAxes = axes('Parent',gcf,'Units','normalized',...
                    'OuterPosition',[0 0 0.75 1/3]);
                
                % Create a stack
                plot_stack = 0;
                
                % Run through for all selected comparison and the reference
                % channel
                for kk = 1:length(comp_channels)+1
                    
                    % Extract the signal comparison segment
                    plot_seg = PA_segments(1,:,kk);
                    
                    % Calcuate the stack
                    plot_stack = plot_stack - max(plot_seg);
                    
                    % Stack plot the 'Total Signal' signal comparison
                    % segment
                    plot(TotalPlotAxes,segment_time,plot_seg+plot_stack);
                    
                    % Modify the stack and hold all
                    plot_stack = plot_stack+min(plot_seg);
                    hold all
                    
                end
                
                % Label the plot accordingly and create a legend
                xlabel(TotalPlotAxes,'Time /s')
                ylabel(TotalPlotAxes,'Amplitude');
                grid(TotalPlotAxes);
                title(TotalPlotAxes,['Comparison to ',reference_channel,...
                    ' in Total Signal'])
                legend(TotalPlotAxes,[reference_channel;comp_channels],...
                    'Location','EastOutside')
                
            end
            
            % Make the figure visible
            set(SeparatePlot,'Visible','on')
            
        end
    end

    function PARoseDispCallback(hObject,eventdata,handles)
        
        % Check if the phase plot axes panel is invisible
        if strcmp(get(PAPlotAxesPanel,'Visible'),'off')
            
            % Reveal the rose plot axes and control panels
            set(PAPlotAxesPanel,'Visible','on')
            set(PAConFunPanel,'Visible','on')
            set(PARosePlotAxesPanel,'Visible','off')
            set(PARoseConFunPanel,'Visible','off')
            
        else
            
            % Otherwise reveal the phase plot axes and control panels
            set(PAPlotAxesPanel,'Visible','off')
            set(PAConFunPanel,'Visible','off')
            set(PARosePlotAxesPanel,'Visible','on')
            set(PARoseConFunPanel,'Visible','on')
            
        end
    end

    function CopyClip(hObject,eventdata,handles)
        
        % 'Copy to Clipboard' function - created by Doke J., 2005.
        % MAT2CLIP, Mathworks. Available from: 
        % http://www.mathworks.com/matlabcentral/fileexchange/8559 
        % [Accessed 19th May 2009].
        mat2clip(eval(get(hObject,'UserData')));
        
    end

end