function varargout = GUI_NotchFilter(varargin)
% GUI_NOTCHFILTER is the programmed GUI for setting notch filters that 
% appears in the program 'LFP Analysis Software 2009'.
% 
% varargout = GUI_NotchFilter(varargin) accepts the position of the parent
% callback window as the first input variable, then the input signal to be
% filtered as the second variable, and finally the original pre-filtered
% signal as the third input variable. It then applies user-defined filters
% to the input signal and returns this filtered signal as the output
% variable, and changes the global variable 'applied_filter' accordingly.
% 
% See also NOTCHFILTERHIDDEN.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Loading required global variables
global applied_filter

% Opening the input variable cell
inputVar = varargin{1};

% Selecting the parent callback window's position
inputPos = inputVar{1};

% Initialising a matrix to store the notch filter figure window's position
% data
NFiltPos = zeros(size(inputPos));

% Setting the width and height of the figure window
NFiltPos(3) = 75; NFiltPos(4) = 9.5;

% Calculating the position of the figure window so that it is centred on
% the parent callback window
NFiltPos(1) = ((inputPos(3)-NFiltPos(3))/2)+inputPos(1);
NFiltPos(2) = ((inputPos(4)-NFiltPos(4))/2)+inputPos(2);

% Checking if no filters have been applied
if isempty(applied_filter)
    
    % Setting the default filter string which corresponds to utlity 
    % frequency
    NFiltMainStr = '49 51; 99 101; 149 151; 199 201; 249 251';
    
else
    
    % If a filter has already been applied, set the filter string to this
    NFiltMainStr = applied_filter;
    
end

% Extracting the segment signal from the input variable
segment_signal = inputVar{2};

% Extracting the original segment signal from the input variable
prev_signal = inputVar{3};

% Setting the saving variable for the inputted string
input_val = [];

% Setting the saving variable for the numerical checking of 'input_val'
return_val = [49 51; 99 101; 149 151; 199 201; 249 251];

% Setting the filtered signal to default to the inputted signal
filtered_signal = segment_signal;

% Creating the figure window
NFiltFigure = figure('Units','characters','MenuBar','none','Name',...
    'Apply Notch Filters','NumberTitle','off','Position',NFiltPos,...
    'ReSize','off','Visible','off');

% Adding copyright text to the bottom right-hand corner
NFiltCopyText = uicontrol('Parent',NFiltFigure,'Units','characters',...
    'BackgroundColor',get(NFiltFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 NFiltPos(3) 1],'String',['Copyright 2009: ',...
    'Eric Young & Andy Kingston '],'Style','text','FontSize',7);

% Creating the panel onto which the components will be constructed
NFiltMainPanel = uipanel('Parent',NFiltFigure,'Units','characters',...
    'Position',[2 4 71 5]);

% Setting the label for the text field
NFiltMainTitle = uicontrol('Parent',NFiltMainPanel,'Units','normalized',...
    'FontWeight','bold','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.9 0.2],'String',['Enter the Values for these Notch ',...
    'Filters'],'Style','text');

% Creating the text field
NFiltMainTextField = uicontrol('Parent',NFiltMainPanel,'Units',...
    'normalized','BackgroundColor','w','Callback',@NFiltMainCallback,...
    'Enable','on','Position',[0.05 0.35 0.9 0.3],'String',NFiltMainStr,...
    'Style','edit','TooltipString',['Please enter numerical values for',...
    'a lower- and upper-limit for each notch filter']);

% Hint on how to enter values in the bottom right-hand side of the panel
NFiltMainHint = uicontrol('Parent',NFiltMainPanel,'Units','normalized',...
    'HorizontalAlignment','right','Position',[0.05 0.15 0.9 0.2],...
    'String',['Leave a space between limits, & a semicolon after each ',...
    'band'],'Style','text');

% Creating the 'Remove Current Filters?' button
NFiltDefault = uicontrol('Parent',NFiltFigure,'Units','characters',...
    'Callback',@NFiltDefaultCallback,'Position',[2 1.5 35.5 2],'String',...
    'Remove Current Filters?');

% Creating the 'Apply Filters?' button
NFiltButton = uicontrol('Parent',NFiltFigure,'Units','characters',...
    'Callback',@NFiltButtonCallback,'Position',[37.5 1.5 35.5 2],'String',...
    'Apply Notch Filter');

% Making the figure window visible once all initialisation tasks have been
% completed
set(NFiltFigure,'Visible','on')

% Setting the program to wait until filter selection has been completed
uiwait(gcf)

% Setting the output arguments
mOutputArgs{1} = filtered_signal;
if nargout>0
    [varargout{1:nargout}] = mOutputArgs{:};
end

    function NFiltMainCallback(hObject,eventdata,handles)
        
        % Obtaining the filter string in the text field
        input_val = get(hObject,'String');
        
        % Converting the string into a numerical matrix
        return_val = str2num(input_val);
        
        % Checking that the string is purely numerical, and that there are
        % two values per filter
        if isempty(return_val)
            
            % Display if the string is not purely numerical
            set(hObject,'String','NaN');
            
            % Stop the program
            return
            
        elseif size(return_val,2)~=2
            
            % Display if the string does not contain two values per filter
            set(hObject,'String','Must have Two Limits per Filter');
            
            % Stop the program
            return
            
        end
    end

    function NFiltDefaultCallback(hObject,eventdata,handles)
        
        % Set the output signal to the original pre-filtered signal if the
        % 'Remove Current Filters?' button is selected
        filtered_signal = prev_signal;
        
        % Remove any filters
        applied_filter = [];
        
        % Resume the program, output the signal and delete the current 
        % figure window
        uiresume(gcbf); delete(gcf);
        
    end

    function NFiltButtonCallback(hObject,eventdata,handles)
        
        % Change the filter to the inputted string in the text field
        applied_filter = get(NFiltMainTextField,'String');
        
        % Apply the required filters
        filtered_signal = NotchFilterHidden(segment_signal);
        
        % Resume the program, output the signal and delete the current
        % figure window
        uiresume(gcbf); delete(gcf);
        
    end

end