function varargout = GUI_SequentialSegmentation(varargin)
% GUI_SEQUENTIALSEGMENTATION is the programmed GUI for performing 
% sequential segmentation that appears in the program 
% 'LFP Analysis Software 2009'.
% 
% varargout = GUI_SequentialSegmenation(varargin) performs sequential
% segmentation on a reference channel signal according the user defined
% variables which govern segmentation start time, segment duration, and
% intervals between segments. It then allows the user to select a segment,
% and returns it, along with its time scale, to the parent figure window.
% 
% See also TIME_SEQUENCE, TIME_SEQUENCE_PLOT.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

%%%%%%%%%%%%%%%%%%%%%%%%%%%DO NOT EDIT THIS FILE%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load the required global variables
global reference_channel sample_rate VoltageScale VoltageValue 
global sequence_indices segment_length SeqSegFigure sequence_counter

% Check if the parent callback window is not from 'GUI_AlternateSegment'
if sequence_counter~=2
    
    % Load other global variables if it passes this check; no need to
    % overwrite these variables unless the parent callback function is the
    % Main Window
    global t1 t2 num_segments
    
end

% Initialising saving variables
segment_signal = []; segment_time = []; input_segment = []; 
input_time = [];

% Creating a figure window for the sequential segmentation function
SeqSegFigure = figure('Units','characters','MenuBar','none','Name',...
    'Sequential Segmentation','NumberTitle','off','Position',...
    [90 5 110 50],'ReSize','off','Visible','off');

% Adding copyright text to the bottom right-hand side of the figure window
SeqSegCopyText = uicontrol('Parent',SeqSegFigure,'Units','characters',...
    'BackgroundColor',get(SeqSegFigure,'Color'),'HorizontalAlignment',...
    'right','Position',[0 0 110 1],'String',['Copyright 2009: Eric ',...
    'Young & Andy Kingston '],'Style','text','FontSize',7);

% Generating panels to house the plot axes, initial variable fields, and
% the segment selection functions
SeqSegPlotPanel = uipanel('Parent',SeqSegFigure,'Units','characters',...
    'Position',[2 17 106 32]);
SeqSegInitialVarPanel = uipanel('Parent',SeqSegFigure,'Units',...
    'characters','Position',[2 1 52.5 15],'Title',['1. Enter ',...
    'Segmentation Variables']);
SeqSegSelectPanel = uipanel('Parent',SeqSegFigure,'Units','characters',...
    'Position',[55.5 1 52.5 15],'Title','2. Select a Segment');

% Loading the icon files for the plot manipulation buttons
zoomplus = load([matlabroot,'/toolbox/matlab/icons/zoomplus.mat']);
zoomminus = load([matlabroot,'/toolbox/matlab/icons/zoomminus.mat']);
panbtn = load([matlabroot,'/toolbox/matlab/icons/pan.mat']);
undock = load('undock.mat');
datacursor = load([matlabroot,'/toolbox/matlab/icons/datatip.mat']);

% Creating a plot axes for the channel signal
SeqSegChannelPlotAxes = axes('Parent',SeqSegPlotPanel,'Units',...
    'normalized','OuterPosition',[0 0.5 1 0.5]);

% Adding the plot manipulation buttons for the channel signal plot
SeqSegChannelZoomIn = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.84375 0.06 0.08],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
SeqSegChannelZoomOut = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.76375 0.06 0.08],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
SeqSegChannelPan = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@PanCallback,'CData',panbtn.cdata,...
    'Position',[0.92 0.67375 0.06 0.08],'Style','togglebutton',...
    'TooltipString','Click to Pan along the Plot','Value',0);
SeqSegChannelUnDock = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,SeqSegChannelPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.59375 0.06 0.08],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Creating a plot axes for the selected segment
SeqSegPlotAxes = axes('Parent',SeqSegPlotPanel,'Units','normalized',...
    'OuterPosition',[0 0 1 0.5]);

% Adding plot manipulation buttons for the segment plot
SeqSegZoomIn = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@ZoomIn,'CData',zoomplus.cdata,'Position',...
    [0.92 0.34375 0.06 0.08],'Style','togglebutton','TooltipString',...
    'Click, Drag, or Scroll along the Plot to Zoom In','Value',0);
SeqSegZoomOut = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@ZoomOut,'CData',zoomminus.cdata,...
    'Position',[0.92 0.26375 0.06 0.08],'Style','togglebutton',...
    'TooltipString','Click, Drag, or Scroll along the Plot to Zoom Out',...
    'Value',0);
SeqSegPan = uicontrol('Parent',SeqSegPlotPanel,'Units','normalized',...
    'Callback',@PanCallback,'CData',panbtn.cdata,'Position',...
    [0.92 0.17375 0.06 0.08],'Style','togglebutton','TooltipString',...
    'Click to Pan along the Plot','Value',0);
SeqSegUnDock = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',{@UnDock,SeqSegPlotAxes},'CData',...
    undock.cdata,'Position',[0.92 0.09375 0.06 0.08],'TooltipString',...
    'Click to Undock Plot into a new Figure');

% Adding a data cursor button for the Segment Selector cursor
SeqSegDataCursor = uicontrol('Parent',SeqSegPlotPanel,'Units',...
    'normalized','Callback',@DataCursor,'CData',...
    datacursor.cdata,'Enable','off','Position',[0.92 0.46 0.06 0.08],...
    'Style','togglebutton','TooltipString',...
    'Click to activate Segment Selector','Value',1);

% Locating all the plot manipulation buttons
allToggleBtns = findall(gcf,'Style','togglebutton');

% Segmentation start time label
SeqSegStartText = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.8 0.6 0.09],'String','Segmentation Start Time:','Style',...
    'text');

% Segmentation start time units
SeqSegStartS = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.85 0.8 0.1 0.09],'String','s','Style','text');

% Segmenation start time text field
SeqSegStartTextField = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','BackgroundColor','w','ButtondownFcn',@ButtonDown,...
    'Callback',@SeqSegInputText,'Position',[0.65 0.8 0.2 0.1],'String',...
    '0','Style','edit');

% Segment duration label
SeqSegDurationText = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.65 0.6 0.09],'String','Segment Duration:','Style','text');

% Segment duration units
SeqSegDurationS = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.85 0.65 0.1 0.09],'String','s','Style','text');

% Segment duration text field
SeqSegDurationTextField = uicontrol('Parent',SeqSegInitialVarPanel,...
    'Units','normalized','BackgroundColor','w','ButtondownFcn',...
    @ButtonDown,'Callback',@SeqSegInputText,'Position',...
    [0.65 0.65 0.2 0.1],'String','0','Style','edit');

% Segment interval label
SeqSegGapText = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.5 0.65 0.09],'String','Segment Gap:','Style','text');

% Segment interval units
SeqSegGapS = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.85 0.5 0.1 0.09],'String','s','Style','text');

% Segment interval text field
SeqSegGapTextField = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','BackgroundColor','w','ButtondownFcn',@ButtonDown,...
    'Callback',@SeqSegInputText,'Position',[0.65 0.5 0.2 0.1],'String',...
    '0','Style','edit');

% Number of segments label
SeqSegNumSegText = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.35 0.65 0.1],'String','Number of Segments:','Style','text');

% Number of segments display
SeqSegNumSegVar = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','Position',[0.65 0.35 0.19 0.1],'String','0','Style',...
    'text');

% Start segmentation button
SeqSegStartButton = uicontrol('Parent',SeqSegInitialVarPanel,'Units',...
    'normalized','Callback',@SeqSegStartButtonCallback,'Enable','off',...
    'Position',[0.05 0.05 0.9 0.25],'String','Start Segmentation Process');

% Segment information text label string
SeqSegInfo = {'Segment Start Time:','Segment End Time:',...
    'Number of Points'};

% Segment information text title
SeqSegInfoTitleText = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','BackgroundColor','w','FontWeight','bold',...
    'HorizontalAlignment','left','Position',[0.05 0.88 0.9 0.08],...
    'String','Segment Information','Style','text');

% Segment information text label
SeqSegInfoText = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Position',[0.05 0.63 0.45 0.25],'String',SeqSegInfo,'Style','text');

% Segment information text values
SeqSegInfoVar = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','BackgroundColor','w','HorizontalAlignment','left',...
    'Position',[0.5 0.63 0.45 0.25],'String',[],'Style','text');

% Segment number title
SeqSegSegNumTitleText = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','FontWeight','bold','HorizontalAlignment','left',...
    'Position',[0.05 0.45 0.9 0.16],'String',['Enter a Segment Number,',...
    ' or Click on a Segment in the Plot'],'Style',...
    'text');

% Segment number label
SeqSegSegNumText = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','HorizontalAlignment','left','Position',...
    [0.05 0.33 0.45 0.09],'String','Segment Number:','Style','text');

% Segment number text field
SeqSegSegNumVar = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','Callback',@SeqSegSegNumVarCallback,'Enable','off',...
    'Position',[0.5 0.33 0.45 0.1],'String',[],'Style','edit');

% Select a segment button
SeqSegSelectButton = uicontrol('Parent',SeqSegSelectPanel,'Units',...
    'normalized','Callback',@SeqSegSelectButtonCallback,'Enable','off',...
    'Position',[0.05 0.05 0.9 0.25],'String','Select this Segment');

% Checking if the parent callback function is 'GUI_AlternateSegment'
if sequence_counter==2
    
    % Disabling the segment duration text field if the check is passed;
    % segment duration needs to be identical to the reference segment to
    % prevent dimension mismatching
    set(SeqSegDurationTextField,'Enable','off','String',num2str(...
        (segment_length-1)/sample_rate))
    
    % Obtain the start time value
    start_time = str2double(get(SeqSegStartTextField,'String'));
    
    % Obtain the segment duration value
    segment_duration = str2double(get(SeqSegDurationTextField,...
        'String'));
    
    % Obtain the segment interval value
    segment_gap = str2double(get(SeqSegGapTextField,'String'));
    
    % Calculate the number of segments
    num_segments = floor((length(evalin('base',...
        reference_channel))-(start_time*sample_rate))/((...
        segment_duration+segment_gap)*sample_rate));
    
    
    % If the number of segments is valid, set the string to
    % this value and enable the start button
    set(SeqSegNumSegVar,'String',num2str(num_segments))
    set(SeqSegStartButton,'Enable','on')
    
    % Enabling the start segmentation button
    set(SeqSegStartButton,'Enable','on')
    
end

% Set the figure window to visible as initialisation is now complete
set(SeqSegFigure,'Visible','on')

% Make the program wait until the function is complete
uiwait(gcf);

% Set the output variables
mOutputArgs{1} = segment_signal;
mOutputArgs{2} = segment_time;

% Assign the output variables to 'varargout'
if nargout>0
    [varargout{1:nargout}] = mOutputArgs{:};
end

    function  ButtonDown(hObject,eventdata)
        
        % If the parent text field is selected, immediately clear the text
        % field
        set(hObject,'Enable','on','String',[])
        uicontrol(hObject);
        
    end

    function ZoomIn(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the butotn is toggled
        if get(hObject,'Value')==1
            
            % If the button is toggled, activate the zooming function
            zoom_handle = zoom;
            
            % Set the zooming function to zoom in, and to zoom only in the
            % horizontal direction
            set(zoom_handle,'Direction','in','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
            % Toggle the Segment Selector button on
            set(SeqSegDataCursor,'Value',1)
            
            % Activate the data cursor
            datacursormode on
            
        end
    end

    function ZoomOut(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check to see if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the zoom function if the button has been toggled on
            zoom_handle = zoom;
            
            % Set the zoom function to zoom out, and to only zoom in the
            % horizontal direction
            set(zoom_handle,'Direction','out','Enable','on','Motion',...
                'horizontal')
            
        else
            
            % Turn the zooming function off if the button is toggled off
            zoom off
            
            % Toggle the Segment Selector button on
            set(SeqSegDataCursor,'Value',1)
            
            % Activate the data cursor
            datacursormode on
            
        end
    end

    function UnDock(hObject,eventdata,axes_handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Create a new figure window on which to export the parent plot
        SeparatePlot = figure('ReSize','on');
        
        % Copy all the objects from the parent plot axes to this new figure
        % window
        copyobj(axes_handles,SeparatePlot);
        
        % Resize the plot axes to fill the new figure window
        set(gca,'OuterPosition',[0 0 1 1])
        
    end

    function PanCallback(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Checking if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activating the pan function if the button has been toggled on
            pan_handles = pan;
            
            % Restricting the pan motion to the horizontal axis only
            set(pan_handles,'Enable','on','Motion','horizontal')
            
        else
            
            % Turning off the pan function if the button has been toggled
            % off
            pan off
            
            % Toggle the Segment Selector button on
            set(SeqSegDataCursor,'Value',1)
            
            % Activate the data cursor
            datacursormode on
            
        end
    end

    function DataCursor(hObject,eventdata,handles)
        
        % Locating all plot manipulation buttons except for the currently
        % selected one
        otherToggleBtns = allToggleBtns;
        otherToggleBtns(allToggleBtns==hObject) = [];
        
        % Set the properties for all other toggle buttons
        for jj = 1:length(otherToggleBtns)
            
            % Toggle off all other plot manipulation buttons
            set(otherToggleBtns(jj),'Value',0)
            
        end
        
        % Check if the button has been toggled on
        if get(hObject,'Value')==1
            
            % Activate the data cursor if the button is toggled on
            dcm_obj = datacursormode(SeqSegFigure);
            
            % Set the data cursor to select a segment when click on the
            % signal
            set(dcm_obj,'DisplayStyle','datatip','SnapToDataVertex',...
                'off','Enable','on','UpdateFcn',@DataCursorCallback)
            
        else
            
            % Turn the data cursor off if the button is toggled off
            datacursormode off
            
        end
    end

    function SeqSegInputText(hObject,eventdata,handles)
        
        % Obtain the string in the parent text field
        input_text = str2double(get(hObject,'String'));
        
        % Check if this string is a numerical value
        if ~isnan(input_text)
            
            % Obtain the start time value
            start_time = str2double(get(SeqSegStartTextField,'String'));
            
            % Obtain the segment duration value
            segment_duration = str2double(get(SeqSegDurationTextField,...
                'String'));
            
            % Obtain the segment interval value
            segment_gap = str2double(get(SeqSegGapTextField,'String'));
            
            % Calculate the number of segments
            num_segments = floor((length(evalin('base',...
                reference_channel))-(start_time*sample_rate))/((...
                segment_duration+segment_gap)*sample_rate));
            
            % Check if the number of segments is valid
            if segment_duration==0||isinf(num_segments)||isnan(...
                    num_segments)
                
                % If the number of segments is invalid, set the displayed
                % string to zero, and disable the start button
                set(SeqSegNumSegVar,'String','0')
                set(SeqSegStartButton,'Enable','off')
                
            else
                
                % If the number of segments is valid, set the string to
                % this value and enable the start button
                set(SeqSegNumSegVar,'String',num2str(num_segments))
                set(SeqSegStartButton,'Enable','on')
                
            end
        else
            
            % If the inputted string is not a valid number display this
            set(hObject,'String','NaN')
            
            % Set the number of segments to zero and disable the start
            % button
            set(SeqSegNumSegVar,'String','0')
            set(SeqSegStartButton,'Enable','off')
            
            % Stop the program
            return
            
        end
    end

    function SeqSegStartButtonCallback(hObject,eventdata,handles)
        
        hold off
        
        % Clear the data cursor and clear any displayed plots
        clear dcm_obj
        cla(SeqSegChannelPlotAxes,'reset')
        cla(SeqSegPlotAxes,'reset')
        
        % Check that there are segments
        if num_segments>0
            
            % Enable the select a segment text field
            set(SeqSegSegNumVar,'BackgroundColor','w','ButtondownFcn',...
                @ButtonDown,'Enable','inactive','String','Enter a Value')
            
            % Obtain the start time value
            start_time = str2double(get(SeqSegStartTextField,'String'));
            
            % Obtain the segment duration value
            segment_duration = str2double(get(SeqSegDurationTextField,...
                'String'));
            
            % Obtain the time interval value
            segment_gap = str2double(get(SeqSegGapTextField,'String'));
            
            % Sequentially segment the channel signal
            sequence_indices = Time_Sequence(segment_duration,...
                segment_gap,start_time,num_segments);
            
            % Plot the segments in the channel plot axes
            Time_Sequence_Plot(SeqSegChannelPlotAxes,evalin('base',...
                reference_channel),sequence_indices,num_segments)
            
            % Enable the data cursor toggle button
            set(SeqSegDataCursor,'Enable','on','Value',1)
            
            % Enable the data cursor
            dcm_obj = datacursormode(SeqSegFigure);
            
            % Set the data cursor to select a segment
            set(dcm_obj,'DisplayStyle','datatip','SnapToDataVertex',...
                'off','Enable','on','UpdateFcn',@DataCursorCallback)
            
        end
    end

    function DataCursorText = DataCursorCallback(empt,eventdata)
        
        % Obtain the position of the selected data point
        DataCursorPosition = get(eventdata,'Position');
        
        % Change the x-axis value to display the time at that point
        DataCursorTime = DataCursorPosition(1)*sample_rate;
        
        % Determine the selected segment's number
        segment_select = find((DataCursorTime>=sequence_indices(1,:)).*...
            (DataCursorTime<=sequence_indices(2,:))==1);
        
        % Check that the selected segment number is not empty
        if ~isempty(segment_select)
            
            % Display the segment number in the segment select text field
            set(SeqSegSegNumVar,'String',num2str(segment_select))
            
            % Check that the segment select number is a valid number
            if ~isnan(str2double(get(SeqSegSegNumVar,'String')))
                
                % Plot the segment in the segment plot axes
                SegmentData();
                
            end
        end
        
        % Modify the displayed text on the data cursor to display time and
        % voltage
        DataCursorText = {['Time: ',num2str(DataCursorPosition(1)),'s'],...
            ['Voltage: ',num2str(DataCursorPosition(2)),...
            VoltageScale{VoltageValue}]};
        
    end

    function SeqSegSegNumVarCallback(hObject,eventdata,handles)
        
        % If a segment number is entered, obtain the string
        segment_select = str2double(get(SeqSegSegNumVar,'String'));
        
        % Check that the string is a numerical value
        if ~isnan(segment_select)
            
            % Plot the segment in the segment plot axes
            SegmentData();
            
        else
            
            % If the string is not a valid numerical value display this
            % message
            set(SeqSegSegNumVar,'String','NaN')
            
        end
    end

    function SegmentData
        
        % Obtain the selected segment number
        segment_select = str2double(get(SeqSegSegNumVar,'String'));
        
        % Check that this is a valid numerical value
        if ~isnan(segment_select)
            
            % Determine the indices of the segment from sequencing indices
            segment_indices = [sequence_indices(1,segment_select),...
                sequence_indices(2,segment_select)];
            
            % Extract the segment from the channel signal
            input_segment = evalin('base',sprintf('%s (%d:%d)',...
                reference_channel,segment_indices(1),...
                segment_indices(2)));
            
            % Calculate the time scale of the segment
            input_time = (segment_indices(1)-1)/sample_rate:...
                1/sample_rate:(segment_indices(2)-1)/sample_rate;
            
            % Determine the length of the segment
            segment_length = length(input_segment);
            
            % Determine the start and end time of the segment
            t1 = input_time(1); t2 = input_time(end);
            
            % Plot the segment in the segment plot axes
            plot(SeqSegPlotAxes,input_time,input_segment)
            grid(SeqSegPlotAxes)
            xlabel(SeqSegPlotAxes,'Time /s')
            ylabel(SeqSegPlotAxes,['Voltage /',VoltageScale{VoltageValue}])
            title(SeqSegPlotAxes,['Segment Between ',num2str(t1,...
                '%.0f'),'s and ',num2str(t2,'%.0f'),'s']);
            
            % Display the time and segment length information
            set(SeqSegInfoVar,'String',{[num2str(t1),'s'],[num2str(t2),...
                's'],num2str(segment_length)})
            
            % Enable the select segment button
            set(SeqSegSelectButton,'Enable','on');
            
        end
    end

    function SeqSegSelectButtonCallback(hObject,eventdata,handles)
        
        % Set the required output variables
        segment_signal = input_segment; segment_time = input_time;
        
        % Check if sequential segmentation has been run through the Main
        % Window before
        if ~isempty(num_segments)
            
            % Reset the counter to one if sequential segmentation has been 
            % used in the Main Window
            sequence_counter = 1;
            
        else
            
            % Reset the counter to zero if sequential segmentation has not
            % been used in the Main Window
            sequence_counter = 0;
            
        end
        
        % Resume the program and delete the current figure window
        uiresume(gcbf); delete(gcf);
        
    end
end