function [decomp_signal,band_power,original_power] = Isolate_Band(...
    input_signal,lower_limit,upper_limit)
% ISOLATE_BAND applies a notch filter at given limits to the frequency of a
% signal to select specific frequency ranges.
% 
% decomp_signal = Isolate_Band(input_signal,lower_limit,upper_limit)
% computes the spectrally decomposed signal of 'input_signal' according to
% the variables 'lower_limit', and 'upper_limit'.
% 
% [decomp_signal,band_power] = Isolate_Band(input_signal,lower_limit,
% upper_limit) returns the decomposed signal, as well as its
% power.
% 
% [decomp_signal,band_power,original_power] = Isolate_Band(input_signal,
% lower_limit,upper_limit) also returns the power of 'input_signal' with
% the variable 'original_power'.
% 
% See also FOURIER, NOTCH_FILTER, BAND_DECOMPOSITION, 
% SEQUENCE_POWER_DISTRIBUTION.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Determining the length of the transformed signal
input_signal_length = length(input_signal);

% Calculating the root-mean-squared power of the original signal
original_power = (norm(input_signal)/sqrt(input_signal_length)).^2;

% Fourier transforming the signal
[transformed_signal,frequency_scale] = Fourier(input_signal);

% Calling back a notch filter
notch_filter = Notch_Filter(frequency_scale,lower_limit,upper_limit);

% Applying the filter
filtered_signal = notch_filter.*transformed_signal;

% Inverse Fourier transforming the signal into its band
decomp_signal = ifft(ifftshift(filtered_signal));

% Determining the length of the filtered signal
decomp_signal_length = length(decomp_signal);

% Calculating the root-mean-squared power of the filtered signal
band_power = (norm(decomp_signal)/sqrt(decomp_signal_length)).^2;