function filtered_signal = NotchFilterHidden(segment_signal)
% NOTCHFILTERHIDDEN applies a notch filter to a signal whilst ensuring that
% it is within the correct dimensions.
% 
% filtered_signal = NotchFilterHidden(segment_signal) applies a notch
% filter to 'segment_signal' and returns the resultant 'filtered_signal' to
% the parent callback function.
% 
% See also NOTCH_FILTER, FOURIER.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global applied_filter

% Checking that filter values exist
if ~isempty(applied_filter)
    
    % Converting the filter value string into a numerical matrix
    notches = str2num(applied_filter);
    
    % Determining the dimnsions of the filter
    dim_notches = size(notches,1);
    
    % Transforming the input signal into the frequency domain
    [fft_signal,frequency] = Fourier(segment_signal);
    
    % Determining whether or not there is only a single notch filter
    if dim_notches==1
        
        % Creating a notch filter according to the user-inputted limits
        notch_filter = 1+(-1*Notch_Filter(frequency,notches(1,...
            1),notches(1,2)));
        
        % Applying the notch filter to the signal
        fft_signal = fft_signal.*notch_filter;
        
        % Returning the filtered signal to the time domain
        filtered_signal = ifft(ifftshift(fft_signal));
        
    else
        
        % Running through all the filter values if there are multiple
        % requested filters
        for i = 1:length(notches)
            
            % Creating a notch filter according to the user-inputted limits
            notch_filter = 1+(-1*Notch_Filter(frequency,notches(i,...
                1),notches(i,2)));
            
            % Applying the notch filter to the signal
            fft_signal = fft_signal.*notch_filter;
            
            % Returning the signal to the time domain
            filtered_signal = ifft(ifftshift(fft_signal));
            
        end
    end
else
    
    % Resetting the output signal to the input signal if no filters have
    % been requested
    filtered_signal = segment_signal;
    
end