function [dphi,coherences] = PhaseCoherence(comp_channels,...
    comp_segments,n,m)
% PHASECOHERENCE determines the phase coherence between a reference segment
% and a number of user-selected comparison segments.
% 
% [dphi,coherences] = PhaseCoherence(comp_channels,comp_segments,n,m)
% calculates the phase coherences between a reference segment (located in
% the first layer of 'comp_segments'), and user-selected comparison
% segments (labelled according to 'comp_channels', and contained within the
% remaining layers of 'comp_segments'). The phase angles are wrapped
% according to a phase-locking ratio determined by 'n' and 'm'. 'dphi' and
% 'coherences' are then returned by the function; the former being a matrix
% of the wrapped phase angles, and the latter being a matrix of phase
% coherence values.
% 
% See also HILBERT.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.46pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading required global variables
global num_bands segment_length

% Quick 2pi calculation
pi2 = pi+pi;

% Determines the number of comparison channels
num_comps = length(comp_channels);

% Initialise saving matrices for the data
dphi = zeros(num_bands+2,segment_length,num_comps);
coherences = zeros(num_bands+2,num_comps);

% Calcluating the Hilbert transform of the reference segment
ht1 = hilbert(comp_segments(:,:,1)');

% Extracting the phase angles of the reference segment
phi1 = angle(ht1');

% Determining the phase coherence between the reference segment and each
% comparison segment
for jj = 1:num_comps
    
    % Calculating the Hilbert transform of each comparison segment
    ht2 = hilbert(comp_segments(:,:,jj+1)');
    
    % Extracting the phase angles of each comparison segment
    phi2 = angle(ht2');
       
    % Wrapping the phase angles between 0 and 2pi
    dphi(:,:,jj) = mod(n*phi1-m*phi2,pi2);
    
    % Determining the phase coherence
    coherences(:,jj) = ((mean(cos(dphi(:,:,jj)),2)).^2 +(mean(sin(...
        dphi(:,:,jj)),2).^2)).^0.5;    
    
end