function [band_powers_time,band_ratios_time,mean_time,mean_power,...
    mean_power_ratios] = Segment_Power_Distribution(decomp_bands,...
    group_size,segment_time)
% SEGMENT_POWER_DISTRIBUTION determines the power distribution across bands
% and their ratio to the original signal.
% 
% [band_powers_time,band_ratios_time,mean_time,mean_power,
% mean_power_ratios] = Segment_Power_Distribution(decomp_bands,group_size,
% segment_time) computes the power distribution across spectrally 
% decomposed frequency bands of a given signal (data obtained from 
% 'decomp_bands') and their ratio to the power obtained from the original 
% signal (via summing the bands' powers; values change due to leakage from 
% DFT). The mean of these values is then taken according to a grouping 
% value to make the resultant plots clearer. 
% 
% See also SEGMENT_POWER_DISTRIBUTION_PLOT.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and
% Astronomy, The University of Nottingham.
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Loading global variables
global num_bands

% Working out the power of each bands over time
band_powers_time = decomp_bands(2:size(decomp_bands,1),:).^2;

% band_powers_time = (norm(transformed_signal)/sqrt(trans_signal_length)).^2

% Reconstruct signal power from bands and create matrix for division;
segment_power_mesh = sum(band_powers_time,1); 
segment_power_mesh = segment_power_mesh(ones(1,size(band_powers_time,...
    1)),:);

% Calculate ratio of each band to reconstructed signal
band_ratios_time = band_powers_time./segment_power_mesh;

% Grouping properties
group_indicies = 1:group_size:length(band_powers_time)-group_size;
num_groups = length(group_indicies);

% Initialising a saving matrix for the group values and an appropriate time 
% scale
mean_power = zeros(num_bands+1,num_groups);
mean_time = segment_time(group_indicies);

% Loop to group data points together
for jj = 1:num_groups
    
   % Determining the mean power of the group
   mean_power(:,jj) = mean(band_powers_time(:,group_indicies(jj):...
       group_indicies(jj)+group_size),2); 

end

% Reconstruct signal power from bands and create matrix for division;
mean_segment_power_mesh = sum(mean_power,1); 
mean_segment_power_mesh = mean_segment_power_mesh(ones(1,size(...
    mean_power,1)),:);

% Calculate ratio of each band to reconstructed signal
mean_power_ratios = mean_power./mean_segment_power_mesh;
    
