function comp_segments = SignalComparison(comp_channels,segment_signal)

% SIGNALCOMPARISON provides a qualitative tool of comparing identical time
% segments of both reference and comparison signals.
% 
% comp_segments = SignalComparison(comp_channels,segment_signal) returns
% the identical time segment of the comparison segments alongside their
% reference segment counter part in a matrix, 'comp_segments', with the
% latter set as the first layer of the 3D matrix. It requires the input
% variables 'comp_channels', the list of selected comparison channels, and
% 'segment_signal', the reference segment, and applies any windows or 
% filters required. It also uses the following global variables, 
% 'num_bands', 'segment_length', 't1', 't2', 'sample_rate', 
% 'filter_counter', 'MCprev_signal', and 'MC_applied_window'.
% 
% Copyright 2009 Eric Young & Andy Kingston, School of Physics and 
% Astronomy, The University of Nottingham
% $ LFP Analysis Software Version 1.0.1 $ $ Date: 09/06/2009 11.45pm $
%
% License
% 
%     This file is part of LFP Analysis Software 2009.
% 
%     LFP Analysis Software 2009 is free software: you can redistribute it 
%     and/or modify it under the terms of the GNU General Public License as 
%     published by the Free Software Foundation, either version 3 of the 
%     License, or (at your option) any later version.
% 
%     LFP Analysis Software 2009 is distributed in the hope that it will be 
%     useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
%     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
%     General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with LFP Analysis Software 2009.  If not, see 
%     <http://www.gnu.org/licenses/>.

% Load required global variables
global num_bands segment_length t1 t2 sample_rate filter_counter
global MCprev_signal MC_applied_window PA_counter

% Determines the number of comparison channels
num_comps = length(comp_channels);

% Calculates the indicies of the segment in relation to its original array
segment_indicies = [t1*sample_rate+1, t2*sample_rate+1];

% Create empty arrays for important data
comp_segments = zeros(num_bands+2,segment_length,num_comps+1);

% Applies a notch filter to the reference segment if one has been applied
if filter_counter==1
    segment_signal = GUI_NotchFilter({get(gcf,...
        'Position'),segment_signal,MCprev_signal});
end

% Split reference signal into bands and add to array
comp_segments(:,:,1) = Band_Decomposition(segment_signal);

% For each channel
for jj = 1:num_comps
    
    % Extract segment for comparison
    comp_segment = evalin('base',[comp_channels{jj},'(',num2str(...
        segment_indicies(1)),':',num2str(segment_indicies(2)),');']);
    
    % Applies a notch filters to the comparison segments
    if filter_counter==1
        comp_segment = NotchFilterHidden(comp_segment);
    end
    
    % Applies a window to the comparison segment but only for phase
    % analysis
    if (strcmp(MC_applied_window,'none')==0)&&(PA_counter==1)
        comp_segment = ApplyWindow(comp_segment,MC_applied_window);
    end
    
    % Separate segment into bands and save
    comp_segments(:,:,jj+1) = Band_Decomposition(comp_segment);
    
end

% Resets the notch filter counter
filter_counter = 0;